@@ -21,11 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
 ****************************************************************************/
 
 /* Funzioni di libreria base */
@@ -37,6 +32,11 @@
 #include <stdlib.h>
 #include <math.h>
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 /* Output stringhe con sync output e parametro */
 int sputsp(const char * s, const char * p)
 	{
@@ -368,7 +368,7 @@ Boolean AutoCorrelation(DLReal * S, int N)
 		for (I = 0; I < N; I++)
 			S[I] = std::real(C[I]) / N;
 
-		delete C;
+		delete[] C;
 
 		return True;
 	}
@@ -385,7 +385,7 @@ Boolean CrossCorrelation(DLReal * S1, DLReal * S2, int N, DLReal * XC)
 			return False;
 		if ((C2 = new DLComplex[2 * N]) == NULL)
 			{
-				delete C1;
+				delete[] C1;
 				return False;
 			}
 
@@ -406,14 +406,14 @@ Boolean CrossCorrelation(DLReal * S1, DLReal * S2, int N, DLReal * XC)
 		for (I = 0; I < 2 * N; I++)
 			C1[I] *= std::conj<DLReal>(C2[I]);
 
-		delete C2;
+		delete[] C2;
 
 		IFft(C1,2 * N);
 
 		for (I = 0; I < 2 * N - 1; I++)
 			XC[I] = std::real(C1[I]) / N;
 
-		delete C1;
+		delete[] C1;
 
 		return True;
 	}
@@ -430,7 +430,7 @@ Boolean GroupDelay(const DLReal * S, const int N, DLReal * GD)
 
 		if ((DHA = new DLComplex[N]) == NULL)
 			{
-				delete HA;
+				delete[] HA;
 				return False;
 			}
 
@@ -446,8 +446,8 @@ Boolean GroupDelay(const DLReal * S, const int N, DLReal * GD)
 		for(I = 0;I < N;I++)
 			GD[I] = std::real(DHA[I] / HA[I]);
 
-		delete HA;
-		delete DHA;
+		delete[] HA;
+		delete[] DHA;
 
 		return True;
 	}
@@ -471,7 +471,7 @@ DLReal LinearDelay(DLReal * Hn,unsigned int N,unsigned int Np,
 
     if ((H1 = new DLComplex[Np]) == NULL)
       {
-        delete(H);
+        delete[](H);
         return(-1);
       }
 
@@ -483,8 +483,8 @@ DLReal LinearDelay(DLReal * Hn,unsigned int N,unsigned int Np,
 
     if (Fft(H,Np) == False)
       {
-        delete(H);
-				delete(H1);
+        delete[](H);
+				delete[](H1);
         return(-1);
       }
 
@@ -496,8 +496,8 @@ DLReal LinearDelay(DLReal * Hn,unsigned int N,unsigned int Np,
 
     if (Fft(H1,Np) == False)
       {
-        delete(H);
-        delete(H1);
+        delete[](H);
+        delete[](H1);
         return(-1);
       }
 
@@ -512,12 +512,11 @@ DLReal LinearDelay(DLReal * Hn,unsigned int N,unsigned int Np,
     for(I = 0;I < Np;I++)
       Sum += (-i*H1[I])/H[I];
 
-    delete(H);
-    delete(H1);
+    delete[](H);
+    delete[](H1);
     return(std::real<DLReal>(-Sum/(i*(DLReal) Np)));
   }
 
-
 /* Conta il numero di righe in un file */
 int FLineCount(const char * FName)
 	{
