@@ -21,11 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
 ****************************************************************************/
 
 /****************************************************************************
@@ -40,6 +35,11 @@
 #include "convol.h"
 #include "fft.h"
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 void Convolve(const DLReal * A,unsigned int NA,const DLReal * B,
 	unsigned int NB,DLReal * R)
   {
@@ -110,7 +110,7 @@ Boolean DFftConvolve(const DLReal * A,unsigned int NA,const DLReal * B,
       if ((FB = new DLComplex[FS]) == NULL)
         {
           if (CA != NULL)
-            delete(FA);
+            delete[](FA);
           return(False);
         }
 
@@ -137,9 +137,9 @@ Boolean DFftConvolve(const DLReal * A,unsigned int NA,const DLReal * B,
       R[I] = FA[I].real();
 
     if (CA == NULL)
-      delete FA;
+      delete[] FA;
     if (CB == NULL)
-      delete FB;
+      delete[] FB;
 
     return(True);
   }
@@ -168,7 +168,7 @@ Boolean DFftConvolve(const DLComplex * A,unsigned int NA,const DLComplex * B,
       if ((FB = new DLComplex[FS]) == NULL)
         {
           if (CA != NULL)
-            delete(FA);
+            delete[](FA);
           return(False);
         }
 
@@ -196,9 +196,9 @@ Boolean DFftConvolve(const DLComplex * A,unsigned int NA,const DLComplex * B,
       R[I] = FA[I];
 
     if (CA == NULL)
-      delete FA;
+      delete[] FA;
     if (CB == NULL)
-      delete FB;
+      delete[] FB;
 
     return(True);
   }
@@ -249,7 +249,7 @@ Boolean OAFftConvolve(const DLReal * A,unsigned int NA,const DLReal * B,
 		    if ((FB = new DLComplex[FS]) == NULL)
 		      {
 		      	if (FAAlloc == True)
-		        	delete(FA);
+		        	delete[](FA);
 		        return(False);
 		      }
 		    FBAlloc = True;
@@ -293,9 +293,9 @@ Boolean OAFftConvolve(const DLReal * A,unsigned int NA,const DLReal * B,
       }
 
 		if (FAAlloc == True)
-    	delete FA;
+    	delete[] FA;
 		if (FBAlloc == True)
-    	delete FB;
+    	delete[] FB;
 
     return(True);
   }
@@ -346,7 +346,7 @@ Boolean OAFftConvolve(const DLComplex * A,unsigned int NA,const DLComplex * B,
 		    if ((FB = new DLComplex[FS]) == NULL)
 		      {
 		      	if (FAAlloc == True)
-		        	delete(FA);
+		        	delete[](FA);
 		        return(False);
 		      }
 		    FBAlloc = True;
@@ -390,9 +390,9 @@ Boolean OAFftConvolve(const DLComplex * A,unsigned int NA,const DLComplex * B,
       }
 
 		if (FAAlloc == True)
-    	delete FA;
+    	delete[] FA;
 		if (FBAlloc == True)
-    	delete FB;
+    	delete[] FB;
 
     return(True);
   }
