@@ -33,6 +33,9 @@ function createbasicplots(ptfname,outdir,fprefix);
 	np = 31768;
 	ptw = 0.3; # 300 ms, psychoacoustic window
 	dlw = 1.5; # Default line width
+	
+	# Default font sizes
+	GDFs = 8;
 
 	# Creates the windows array
 	wa = linspace(ew,sw,np);
@@ -49,6 +52,9 @@ function createbasicplots(ptfname,outdir,fprefix);
 	clf();
 	figure(1,"visible","off");
 	
+	# Set default font size
+	set(0,"defaultaxesfontsize",GDFs)
+	
 	# Plot the frequency dependent windowing curves
 	for gn = 1:10
 		plot(wa,fslprefilt(sf,sw,ef,ew,0.2 * gn,np),sprintf(";WE = %.1f;",0.2 * gn),"color",hsv2rgb([0.9 * (gn - 1) / 9, 1, 0.75]),"LineWidth",dlw);
@@ -64,7 +70,7 @@ function createbasicplots(ptfname,outdir,fprefix);
 	safetics("y",0:1000:21000);
 	
 	# Print to the output file
-	print([ outdir fprefix "-Linear.eps" ],"-depsc");
+	print([ outdir fprefix "-Linear.eps" ],"-depsc2");
 	
 	# Report the stage
 	disp("Frequency dependent windowing, semilogy scale...");
@@ -90,7 +96,7 @@ function createbasicplots(ptfname,outdir,fprefix);
 	safetics("y",[10,20,30,50,100,200,300,500,1000,2000,3000,5000,10000,20000]);
 	
 	# Print to the output file
-	print([ outdir fprefix "-SemiLogY.eps" ],"-depsc");
+	print([ outdir fprefix "-SemiLogY.eps" ],"-depsc2");
 	
 	# Report the stage
 	disp("Frequency dependent windowing, semilogx scale...");
@@ -116,7 +122,7 @@ function createbasicplots(ptfname,outdir,fprefix);
 	safetics("y",0:1000:21000);
 	
 	# Print to the output file
-	print([ outdir fprefix "-SemiLogX.eps" ],"-depsc");
+	print([ outdir fprefix "-SemiLogX.eps" ],"-depsc2");
 		
 	# Report the stage
 	disp("Frequency dependent windowing, loglog scale...");
@@ -142,7 +148,7 @@ function createbasicplots(ptfname,outdir,fprefix);
 	safetics("y",[10,20,30,50,100,200,300,500,1000,2000,3000,5000,10000,20000]);
 	
 	# Print to the output file
-	print([ outdir fprefix "-LogLog.eps" ],"-depsc");
+	print([ outdir fprefix "-LogLog.eps" ],"-depsc2");
 
 	# Report the stage
 	disp("Frequency dependent windowing, loglog scale with gabor limit...");
@@ -169,7 +175,7 @@ function createbasicplots(ptfname,outdir,fprefix);
 	safetics("y",[10,20,30,50,100,200,300,500,1000,2000,3000,5000,10000,20000]);
 	
 	# Print to the output file
-	print([ outdir fprefix "-Gabor.eps" ],"-depsc");
+	print([ outdir fprefix "-Gabor.eps" ],"-depsc2");
 
 	# Report the stage
 	disp("Frequency dependent windowing, time-frequency jail...");
@@ -194,7 +200,7 @@ function createbasicplots(ptfname,outdir,fprefix);
 	safetics("y",[10,20,30,50,100,200,300,500,1000,2000,3000,5000,10000,20000]);
 	
 	# Print to the output file
-	print([ outdir fprefix "-Jail.eps" ],"-depsc");
+	print([ outdir fprefix "-Jail.eps" ],"-depsc2");
 
 	# Report the stage
 	disp("Frequency dependent windowing, psychoacoustic bandwidth comparison...");
@@ -220,15 +226,15 @@ function createbasicplots(ptfname,outdir,fprefix);
 	hold("off");
 	
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Frequency (Hz)");
 	axis([0.01, 21, 0.5, 10000]);
 	safetics("x",[0.01,0.02,0.03,0.05,0.1,0.2,0.3,0.5,1,2,3,5,10,20]);
 	safetics("y",[0.5,1,2,3,5,10,20,30,50,100,200,300,500,1000,2000,3000,5000,10000]);
-	legend(2);
+	legend("location","northeast");
 	
 	# Print to the output file
-	print([ outdir fprefix "-BWidthCmp.eps" ],"-depsc");
+	print([ outdir fprefix "-BWidthCmp.eps" ],"-depsc2");
 
 	# Report the stage
 	disp("Frequency dependent windowing, proportional and bilinear comparison...");
@@ -258,7 +264,7 @@ function createbasicplots(ptfname,outdir,fprefix);
 	safetics("y",[10,20,30,50,100,200,300,500,1000,2000,3000,5000,10000,20000]);
 	
 	# Print to the output file
-	print([ outdir fprefix "-BPComparison.eps" ],"-depsc");
+	print([ outdir fprefix "-BPComparison.eps" ],"-depsc2");
 
 	# Report the stage
 	disp("Transfer functions...");
@@ -312,14 +318,14 @@ function createbasicplots(ptfname,outdir,fprefix);
 	hold("off");
 	
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Frequency (Hz)");
 	axis([0.01, 22.05, -30, 9]);
 	safetics("x",[0.01,0.02,0.03,0.05,0.1,0.2,0.3,0.5,1,2,3,5,10,20]);
 	safetics("y",-30:3:9);
 	
 	# Print to the output file
-	print([ outdir fprefix "-DTFCmp.eps" ],"-depsc");
+	print([ outdir fprefix "-DTFCmp.eps" ],"-depsc2");
 	
 	# Remove variables no longer used
 	clear sf sw ef ew wa gl;	
@@ -377,14 +383,14 @@ function createbasicplots(ptfname,outdir,fprefix);
 	hold("off");
 	
 	grid("on");
-	xlabel("Frequency (KHz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	axis([0.02, 20, -35, 25]);
 	safetics("x",[0.02,0.03,0.05,0.1,0.2,0.3,0.5,1,2,3,5,10,20]);
 	safetics("y",-35:5:25);
 	
 	# Print to the output file
-	print([ outdir fprefix "-SpectralEnvelope.eps" ],"-depsc");
+	print([ outdir fprefix "-SpectralEnvelope.eps" ],"-depsc2");
 	
 	# Remove variables no longer used
 	clear ptf ptr ptev ptus ptss;	
