@@ -29,7 +29,7 @@
 ## outdir = output directory for graph files
 ## fprefix = prefix for graph files
 ## fext = extension for graph files, default '.eps'
-## fdevice = print device for graph files, default '-depsc'
+## fdevice = print device for graph files, default '-depsc2'
 ##  
 ## Along with the device any other option supported by the Octave 
 ## 'print' command may be specified. For example setting fdevice to:
@@ -41,7 +41,7 @@
 ## Sample rate of ir1 and ir2 *must* be 44.1 kHz
 ##
 
-function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fdevice = '-depsc')
+function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fdevice = '-depsc2')
 	# Find the impulse center if needed
 	if (ic1 < 0)
 		[irm1,ic1] = max(abs(hilbert(ir1)));	
@@ -54,6 +54,16 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 		irm2 = max(abs(hilbert(ir2)));	
 	endif
 	
+	# Frequency axis tics
+	# gfp = [0.02,0.03,0.05,0.07,0.1,0.15,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,15,20];
+	
+	# Generate the labels from the tics
+	# gfl = num2str(gfp','%.2g');	
+	
+	# Denser tics, with partial explicit labels
+	gfp = [0.02,0.03,0.04,0.05,0.06,0.07,0.08,0.09,0.1,0.15,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1,1.5,2,3,4,5,6,7,8,9,10,15,20];
+	gfl = [ "0.02";"0.03";" ";"0.05";" ";"0.07";" ";" ";"0.1";"0.15";"0.2";"0.3";" ";"0.5";" ";"0.7";" ";" ";"1";"1.5";"2";"3";" ";"5";" ";"7";" ";" ";"10";"15";"20" ];
+	
 	# Normalize the impulse responses to the norm
 	rms1 = norm(ir1);
 	ir1 = ir1(:)/rms1;
@@ -73,11 +83,14 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	
 	# Colormap, line colors and line width for 3d surface plots
 	EDLw = 0.25;
-	EDCMap = hsv2rgb([linspace(0.60,0.00,256)', 1.0 * ones(256,1), 0.65 * ones(256,1)]);	
+	EDCMap = hsv2rgb([linspace(0.50,0.00,256)', 1.0 * ones(256,1), 0.65 * ones(256,1)]);	
 	ULColor = [0.85, 0.85, 0.85];
 	LLColor = [0.85, 0.85, 0.85];	
 	
-	# Enable contour display	when set to > 0
+	# Default font sizes
+	GDFs = 8;
+	
+	# Enable contour display when set to > 0
 	surcntenable = 0;
 	mapcntenable = 0;
 	
@@ -114,8 +127,11 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	clf();
 	figure(1,"visible","off");
 	
+	# Set default font size
+	set(0,"defaultaxesfontsize",GDFs)
+	
 	# Plot the step responses 1
-	subplot(2,1,1);	
+	subplot(2,1,1);
 	plot(1000 * ((([0:length(ir1step)-1])/(rf*fs))-((irp/fs) + ((rfl + 1)/(2*rf*fs)))),ir1step,["1;" it1 ";"],"LineWidth",DLW);
 	axis([-5, 25]);
 	grid("on");
@@ -610,7 +626,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");
-	safetics("x",[1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 		
 	# Save the axis range
 	g1ax = axis();
@@ -622,7 +638,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");	
-	safetics("x",[1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	
 	# Save the axis range
 	g2ax = axis();
@@ -665,7 +681,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Plot the phase response 2
@@ -675,7 +691,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 
 	# Print to the output file
@@ -713,7 +729,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");	
-	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-15:3:15);
 	
 	# Save the axis range
@@ -726,7 +742,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");	
-	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-15:3:15);
 	
 	# Save the axis range
@@ -748,7 +764,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	gax(4) = 3 * ceil(gax(4) / 3);
 	
 	# Set the uniforma axis range
-	subplot(2,1,1);	
+	subplot(2,1,1);		
 	axis(gax);
 	safetics("y",gax(3):3:gax(4));
 	subplot(2,1,2);	
@@ -770,7 +786,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Plot the phase response 2
@@ -780,7 +796,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Print to the output file
@@ -816,9 +832,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(fs * ixg / length(ir1w),20 * log10(abs(ir1w(1 + ixg))),["1;" it1 ";"],"LineWidth",DLW);
 	axis([20, 200]);
 	grid("on");
-	xlabel("Frequency (Hz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");	
-	safetics("x",[20,30,50,70,100,160,200]);
+	safetics("x",1000 * gfp,gfl);
 	
 	# Save the axis range
 	g1ax = axis();
@@ -828,9 +844,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(fs * ixg / length(ir2w),20 * log10(abs(ir2w(1 + ixg))),["3;" it2 ";"],"LineWidth",DLW);
 	axis([20, 200]);
 	grid("on");
-	xlabel("Frequency (Hz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Amplitude (dB)");	
-	safetics("x",[20,30,50,70,100,160,200]);
+	safetics("x",1000 * gfp,gfl);
 	
 	# Save the axis range
 	g2ax = axis();
@@ -871,9 +887,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(fs * ixg / length(ir1w),180 * angle(ir1w(1 + ixg))/pi,["1;" it1 ";"],"LineWidth",DLW);
 	axis([20, 200, -180, 180]);
 	grid("on");
-	xlabel("Frequency (Hz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[20,30,50,70,100,160,200]);
+	safetics("x",1000 * gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Plot the phase response 2
@@ -881,9 +897,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	semilogx(fs * ixg / length(ir2w),180 * angle(ir2w(ixg))/pi,["3;" it2 ";"],"LineWidth",DLW);
 	axis([20, 200, -180, 180]);
 	grid("on");
-	xlabel("Frequency (Hz)");
+	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[20,30,50,70,100,160,200]);
+	safetics("x",1000 * gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Print to the output file
@@ -934,7 +950,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	
 	# Save the axis range
 	g1ax = axis();
@@ -946,7 +962,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	
 	# Save the axis range
 	g2ax = axis();
@@ -1010,7 +1026,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Plot the phase response 2
@@ -1020,7 +1036,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Print to the output file
@@ -1068,7 +1084,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	
 	# Save the axis range
 	g1ax = axis();
@@ -1080,7 +1096,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	
 	# Save the axis range
 	g2ax = axis();
@@ -1144,7 +1160,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Plot the phase response 2
@@ -1154,7 +1170,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 
 	# Print to the output file
@@ -1202,7 +1218,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	
 	# Save the axis range
 	g1ax = axis();
@@ -1214,7 +1230,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	
 	# Save the axis range
 	g2ax = axis();
@@ -1278,7 +1294,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Plot the phase response 2
@@ -1288,7 +1304,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Frequency (kHz)");
 	ylabel("Phase (deg)");	
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	safetics("y",-180:30:180);
 	
 	# Print to the output file
@@ -1369,19 +1385,19 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	# Disable holding the plot and set graph parameters
 	subplot(2,1,1);
 	hold("off");
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	grid("on");
-	legend(3);
+	legend("location","southwest");
 
 	subplot(2,1,2);
 	hold("off");
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	grid("on");
-	legend(3);
+	legend("location","southwest");
 	
 	# Save the axis range
 	subplot(2,1,1);
@@ -1492,19 +1508,19 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	# Disable holding the plot and set graph parameters
 	subplot(2,1,1);
 	hold("off");
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	grid("on");
-	legend(3);
+	legend("location","southwest");
 
 	subplot(2,1,2);
 	hold("off");
-	safetics("x",[0.02,0.05,0.1,0.2,0.3,0.5,0.7,1,1.5,2,3,5,7,10,16,20]);
+	safetics("x",gfp,gfl);
 	xlabel("Frequency (kHz)");
 	ylabel("Magnitude (dB)");
 	grid("on");
-	legend(3);
+	legend("location","southwest");
 	
 	# Save the axis range
 	subplot(2,1,1);
@@ -1593,7 +1609,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[2,5,8,12,16,20]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -1614,7 +1630,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[2,5,8,12,16,20]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -1645,7 +1661,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[2,5,8,12,16,20]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -1666,7 +1682,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[2,5,8,12,16,20]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -1728,7 +1744,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -1749,7 +1765,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -1780,7 +1796,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -1801,7 +1817,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -1869,9 +1885,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 20, 200, -33, 1]);
 	grid("on");
 	xlabel("Time (s)");
-	ylabel("Frequency (Hz)");
+	ylabel("Frequency (kHz)");
 	zlabel("Mag. (dB)");	
-	safetics("y",[20,50,80,120,160,200]);
+	safetics("y",1000 * gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -1890,9 +1906,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 20, 200, -33, 1]);
 	grid("on");
 	xlabel("Time (s)");
-	ylabel("Frequency (Hz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[20,50,80,120,160,200]);
+	safetics("y",1000 * gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -1921,9 +1937,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 20, 200, -33, 1]);
 	grid("on");
 	xlabel("Time (s)");
-	ylabel("Frequency (Hz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[20,50,80,120,160,200]);
+	safetics("y",1000 * gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -1942,9 +1958,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 20, 200, -33, 1]);
 	grid("on");
 	xlabel("Time (s)");
-	ylabel("Frequency (Hz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[20,50,80,120,160,200]);
+	safetics("y",1000 * gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -2006,7 +2022,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[2,5,8,12,16,20]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -2027,7 +2043,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[2,5,8,12,16,20]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -2058,7 +2074,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[2,5,8,12,16,20]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -2079,7 +2095,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[2,5,8,12,16,20]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -2122,7 +2138,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	S2 = S2/max(S2(:));
 	S2 = 20 * log10(max(S2,10^(-30/20)));
 
-		# Open a new plot
+	# Open a new plot
 	newplot();
 	clf();
 	figure(1,"visible","off");
@@ -2141,7 +2157,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -2162,7 +2178,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -2193,7 +2209,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -2214,7 +2230,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[0.2,0.5,0.8,1.2,1.6,2.0]);
+	safetics("y",gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -2282,9 +2298,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 20, 200, -33, 1]);
 	grid("on");
 	xlabel("Time (s)");
-	ylabel("Frequency (Hz)");
+	ylabel("Frequency (kHz)");
 	zlabel("Mag. (dB)");	
-	safetics("y",[20,50,80,120,160,200]);
+	safetics("y",1000 * gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -2303,9 +2319,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 20, 200, -33, 1]);
 	grid("on");
 	xlabel("Time (s)");
-	ylabel("Frequency (Hz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[20,50,80,120,160,200]);
+	safetics("y",1000 * gfp,gfl);
 	safetics("z",-30:6:0);
 	view(15, 45);
 	colormap(EDCMap);
@@ -2334,9 +2350,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 20, 200, -33, 1]);
 	grid("on");
 	xlabel("Time (s)");
-	ylabel("Frequency (Hz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[20,50,80,120,160,200]);
+	safetics("y",1000 * gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -2355,9 +2371,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	axis([-tbs, tbe, 20, 200, -33, 1]);
 	grid("on");
 	xlabel("Time (s)");
-	ylabel("Frequency (Hz)");	
+	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	safetics("y",[20,50,80,120,160,200]);
+	safetics("y",1000 * gfp,gfl);
 	safetics("z",-30:6:0);
 	view(345, 45);
 	colormap(EDCMap);
@@ -2389,6 +2405,10 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	# 1 ms spectrogram window
 	swl = 44;
 	
+	# Spaziatura tics asse x e y
+	xtsp = 2.5;
+	ytsp = 2;
+	
 	# Computes the spectrogram window
 	wind = [blackman(swl)' zeros(1,sfs-swl)]';
 	
@@ -2419,7 +2439,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
+	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",-tbs:xtsp:tbe);
+	safetics("y",0:ytsp:(fs / 2000));
 	colormap(EDCMap);	
 	colorbar("EastOutside");
 	title(it1);
@@ -2433,7 +2455,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
+	safetics("x",-tbs:xtsp:tbe);
+	safetics("y",0:ytsp:(fs / 2000));
+	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
 	colormap(EDCMap);	
 	colorbar("EastOutside");
 	title(it2);	
@@ -2458,7 +2482,11 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	mlb = -90;
 	
 	# 20 ms spectrogram window
-	swl = 882;	
+	swl = 882;
+	
+	# Spaziatura tics asse x e y
+	xtsp = 25;
+	ytsp = 2;
 	
 	# Computes the spectrogram window
 	wind = [blackman(swl)' zeros(1,sfs-swl)]';
@@ -2490,7 +2518,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
+	safetics("x",-tbs:xtsp:tbe);
+	safetics("y",0:ytsp:(fs / 2000));
+	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
 	colormap(EDCMap);	
 	colorbar("EastOutside");
 	title(it1);
@@ -2504,7 +2534,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (ms)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
+	safetics("x",-tbs:xtsp:tbe);
+	safetics("y",0:ytsp:(fs / 2000));
+	text(1.1 * tbe,fs / 4000,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
 	colormap(EDCMap);	
 	colorbar("EastOutside");
 	title(it2);	
@@ -2540,6 +2572,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	
 	# Morlet wavelet
 	ceft = 2;
+	
+	# Spaziatura tics asse x
+	xtsp = 2;
 			
 	# Computes the cicle points
 	cecp = linspace(cecb,cece,cenc);
@@ -2548,7 +2583,7 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	cebs = 2 ^ (log2(ceef / cesf) / cenf); 
 	cefp = logspace(log10(2 * cesf / (cebs * fs)),log10(2 * ceef / (cebs * fs)),cenf);
 	
-	# Computes the scalograms
+	# Computes the Morlet cycle/octave scalogram
 	ce1 = tfir(ir1, ic1, cecp, cefp, cefl, ceat, ceuf, ceft, cewm);
 	ce2 = tfir(ir2, ic2, cecp, cefp, cefl, ceat, ceuf, ceft, cewm);
 			
@@ -2608,8 +2643,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
-	zlabel("Mag. (norm.)");	
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	zlabel("Mag. (norm.)");
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	set(gca(),"yscale","log")
 	view(15, 45);
@@ -2630,8 +2666,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
-	zlabel("Mag. (norm.)");	
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	zlabel("Mag. (norm.)");
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	set(gca(),"yscale","log")
 	view(15, 45);
@@ -2662,8 +2699,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
-	zlabel("Mag. (norm.)");	
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	zlabel("Mag. (norm.)");
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	set(gca(),"yscale","log")
 	view(345, 45);
@@ -2684,8 +2722,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
-	zlabel("Mag. (norm.)");	
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	zlabel("Mag. (norm.)");
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	set(gca(),"yscale","log")
 	view(345, 45);
@@ -2720,8 +2759,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm)");
-	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center");
-	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);
+	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",(rcenf-1) * log(gfp / 0.02) / log(20 / 0.02),gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);	
 	colormap(EDCMap);	
 	colorbar("EastOutside");
@@ -2736,8 +2776,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm)");
-	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center");
-	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);
+	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",(rcenf-1) * log(gfp / 0.02) / log(20 / 0.02),gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);	
 	colormap(EDCMap);	
 	colorbar("EastOutside");
@@ -2769,7 +2810,8 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",-25:5:5);
 	set(gca(),"yscale","log")
 	view(15, 45);
@@ -2791,7 +2833,8 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",-25:5:5);
 	set(gca(),"yscale","log")
 	view(15, 45);
@@ -2823,7 +2866,8 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",-25:5:5);
 	set(gca(),"yscale","log")
 	view(345, 45);
@@ -2845,7 +2889,8 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",-25:5:5);
 	set(gca(),"yscale","log")
 	view(345, 45);
@@ -2880,8 +2925,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
-	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);
+	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",(rcenf-1) * log(gfp / 0.02) / log(20 / 0.02),gfl);
 	safetics("z",-25:5:5);
 	colormap(EDCMap);	
 	colorbar("EastOutside");
@@ -2896,8 +2942,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");	
-	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
-	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
+	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",(rcenf-1) * log(gfp / 0.02) / log(20 / 0.02),gfl);
 	safetics("z",-25:5:5);
 	colormap(EDCMap);	
 	colorbar("EastOutside");
@@ -2934,6 +2981,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	
 	# Morlet wavelet
 	ceft = 2;
+	
+	# Spaziatura tics asse x
+	xtsp = 2;
 			
 	# Computes the cicle points
 	cecp = linspace(cecb,cece,cenc);
@@ -2946,9 +2996,6 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	ce1 = tfir(ir1, ic1, cecp, cefp, cefl, ceat, ceuf, ceft, cewm);
 	ce2 = tfir(ir2, ic2, cecp, cefp, cefl, ceat, ceuf, ceft, cewm);
 	
-	# Remaps the frequency points for plotting
-	cefp = logspace(log10(2 * cesf / fs),log10(2 * ceef / fs),cenf);
-	
 	# Computes the envelope
 	for I = 1:cenf
 		ce1(I,:) = abs(hilbert(ce1(I,:)));
@@ -3005,8 +3052,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
-	zlabel("Mag. (norm.)");	
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	zlabel("Mag. (norm.)");
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	set(gca(),"yscale","log")
 	view(15, 45);
@@ -3027,8 +3075,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
-	zlabel("Mag. (norm.)");	
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	zlabel("Mag. (norm.)");
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	set(gca(),"yscale","log")
 	view(15, 45);
@@ -3059,8 +3108,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
-	zlabel("Mag. (norm.)");	
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	zlabel("Mag. (norm.)");
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	set(gca(),"yscale","log")
 	view(345, 45);
@@ -3081,8 +3131,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	grid("on");
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
-	zlabel("Mag. (norm.)");	
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	zlabel("Mag. (norm.)");
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	set(gca(),"yscale","log")
 	view(345, 45);
@@ -3117,8 +3168,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm)");	
-	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center");
-	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
+	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",(rcenf-1) * log(gfp / 0.02) / log(20 / 0.02),gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	colormap(EDCMap);	
 	colorbar("EastOutSide");
@@ -3133,8 +3185,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (norm)");	
-	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center");
-	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
+	text(1.1 * cece,rcenf / 2,"Mag. (norm)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",(rcenf-1) * log(gfp / 0.02) / log(20 / 0.02),gfl);
 	safetics("z",[0.25,0.5,0.75,1.0]);
 	colormap(EDCMap);	
 	colorbar("EastOutSide");
@@ -3166,7 +3219,8 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",-25:5:5);
 	set(gca(),"yscale","log")
 	view(15, 45);
@@ -3188,7 +3242,8 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",-25:5:5);
 	set(gca(),"yscale","log")
 	view(15, 45);
@@ -3220,7 +3275,8 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",-25:5:5);
 	set(gca(),"yscale","log")
 	view(345, 45);
@@ -3242,7 +3298,8 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	safetics("y",[0.02,0.05,0.1,0.2,0.5,1,2,5,10,20]);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",gfp,gfl);
 	safetics("z",-25:5:5);
 	set(gca(),"yscale","log")
 	view(345, 45);
@@ -3277,8 +3334,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
-	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
+	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",(rcenf-1) * log(gfp / 0.02) / log(20 / 0.02),gfl);
 	safetics("z",-25:5:5);
 	colormap(EDCMap);	
 	colorbar("EastOutside");
@@ -3293,8 +3351,9 @@ function createdrcplots(ir1,ic1,it1,ir2,ic2,it2,outdir,fprefix,fext = '.eps',fde
 	xlabel("Time (cycles)");
 	ylabel("Frequency (kHz)");	
 	zlabel("Mag. (dB)");
-	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center");
-	safetics("y",linspace(0,rcenf-1,10),["0.02";"0.05";"0.1";"0.2";"0.5";"1";"2";"5";"10";"20"]);	
+	text(1.1 * cece,rcenf / 2,"Mag. (dB)","Rotation",90,"HorizontalAlignment","center","fontsize",GDFs);
+	safetics("x",cecb:xtsp:cece);
+	safetics("y",(rcenf-1) * log(gfp / 0.02) / log(20 / 0.02),gfl);
 	safetics("z",-25:5:5);
 	colormap(EDCMap);	
 	colorbar("EastOutside");
