@@ -21,14 +21,9 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
-		This program uses  also the FFT  routines from  Takuya Ooura and
-		the GNU Scientific  Library (GSL).  Many thanks  to Takuya Ooura
-		and the GSL developers for these efficient routines.
+		This program uses the FFT  routines from  Takuya Ooura and the GNU
+		Scientific  Library (GSL).  Many thanks  to Takuya Ooura and the GSL
+		developers for these efficient routines.
 
 ****************************************************************************/
 
@@ -42,7 +37,7 @@
 #include "slprefilt.h"
 #include "baselib.h"
 #include "level.h"
-#include "parsecfg.h"
+#include "cfgparse.h"
 #include "convol.h"
 #include "hd.h"
 #include "toeplitz.h"
@@ -59,8 +54,13 @@
 #include <fenv.h>
 
 /* Versione corrente */
-#define DRCVersion "3.2.0"
-#define DRCCopyright "2002-2011"
+#define DRCVersion "3.2.1"
+#define DRCCopyright "2002-2012"
+
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
 
 /* Header iniziale programma */
 void ShowDRCHeader(void)
@@ -259,11 +259,13 @@ int main(int argc, char * argv[])
 
 		/* Recupera la configurazione */
 		sputs("Parsing configuration file...");
-		if (cfgParse(DRCFile,CfgParmsDef,CFG_SIMPLE) != CFG_NO_ERROR)
+		if (CfgParse(DRCFile,CfgParmsDef,CfgSimple) <= 0)
 			{
 				/* Dealloca le informazioni parsing command line */
 				FreeCmdLine(OptData, CfgParmsDef);
+				CfgFree(CfgParmsDef);
 
+				sputs(CfgGetLastErrorDsc());
 				sputs("Configuration file parsing error.");
 				return 1;
 			}
@@ -279,6 +281,7 @@ int main(int argc, char * argv[])
 			{
 				/* Dealloca le informazioni parsing command line */
 				FreeCmdLine(OptData, CfgParmsDef);
+				CfgFree(CfgParmsDef);
 
 				sputs("Base configuration setup error.");
 				return 1;
@@ -292,7 +295,7 @@ int main(int argc, char * argv[])
 		if (CheckDRCCfg(&Cfg) != 0)
 			{
 				/* Libera la memoria della struttura di configurazione */
-				FreeCfgStruct(CfgParmsDef);
+				CfgFree(CfgParmsDef);
 				free(DRCFile);
 				return 1;
 			}
@@ -534,7 +537,7 @@ int main(int argc, char * argv[])
 								MCFilter[I] = MPSig[I];
 
 							/* Dealloca l'array deconvoluzione */
-							delete MPSig;
+							delete[] MPSig;
 						break;
 					}
 
@@ -561,8 +564,8 @@ int main(int argc, char * argv[])
 					}
 
 				/* Deallocazione array */
-				delete MCFilter;
-				delete InSig;
+				delete[] MCFilter;
+				delete[] InSig;
 
 				/* Determina la dimensione della finestra di uscita */
 				if (Cfg.MCOutWindow > 0)
@@ -635,9 +638,9 @@ int main(int argc, char * argv[])
 					}
 
 				/* Deallocazione array */
-				delete MCFilterFreqs;
-				delete MCFilterM;
-				delete MCFilterP;
+				delete[] MCFilterFreqs;
+				delete[] MCFilterM;
+				delete[] MCFilterP;
 			}
     else
       {
@@ -806,7 +809,7 @@ int main(int argc, char * argv[])
 			}
 
 		/* Dealloca il segnale di ingresso */
-		delete MCOutSig;
+		delete[] MCOutSig;
 
 		/*********************************************************************************/
 		/* Prefiltratura componente MP */
@@ -900,7 +903,7 @@ int main(int argc, char * argv[])
 			}
 
 		/* Dealloca la componente MP */
-		delete MPSig;
+		delete[] MPSig;
 
 		/* Calcola la dimensione per la finestratura finale */
 		if (Cfg.MPPFFinalWindow > 0)
@@ -996,7 +999,7 @@ int main(int argc, char * argv[])
 					MPPFSig[J] = MPSig[I];
 
 				/* Dealloca l'array deconvoluzione */
-				delete MPSig;
+				delete[] MPSig;
 			}
 
 		/* Verifica se si deve effettuare la finestratura finale */
@@ -1066,8 +1069,8 @@ int main(int argc, char * argv[])
 					EPSig[I] = EPPFSig[J];
 
 				/* Dealloca l'array temporaneo convoluzione */
-				delete MPEPSig;
-				delete EPPFSig;
+				delete[] MPEPSig;
+				delete[] EPPFSig;
 			}
 
 
@@ -1159,7 +1162,7 @@ int main(int argc, char * argv[])
 			}
 
 		/* Dealloca la componente EP */
-		delete EPSig;
+		delete[] EPSig;
 
 		/* Determina la lunghezza della componente dopo la finestratura */
 		if (Cfg.EPPFFinalWindow > 0)
@@ -1218,7 +1221,7 @@ int main(int argc, char * argv[])
 								EPPFSig[J] = EPSig[I];
 
 							/* Dealloca gli array per la deconvoluzione omomorfa */
-							delete EPSig;
+							delete[] EPSig;
 						break;
 					}
 			}
@@ -1283,8 +1286,8 @@ int main(int argc, char * argv[])
 				/* Dealloca gli array MP/EP finestrati */
 				if (Cfg.ISType[0] == 'L')
 					{
-						delete MPPFSig;
-						delete EPPFSig;
+						delete[] MPPFSig;
+						delete[] EPPFSig;
 					}
 
 				/* Finestratura segnale risultante */
@@ -1328,7 +1331,7 @@ int main(int argc, char * argv[])
 
 				/* Dealloca gli array */
 				if (Cfg.ISType[0] != 'L')
-					delete MPEPSig;
+					delete[] MPEPSig;
 			}
 
 		/*********************************************************************************/
@@ -1386,7 +1389,7 @@ int main(int argc, char * argv[])
 						ISMPEPSig[J] =	MPEPSig[I];
 
 					/* Dealloca il segnale composto MP/EP */
-					delete MPEPSig;
+					delete[] MPEPSig;
 
 					/* Inversione e ritardo segnale */
 					sputs("Signal delay/reverse.");
@@ -1421,8 +1424,8 @@ int main(int argc, char * argv[])
 						}
 
 					/* Dealloca gli array */
-					delete ISRevSig;
-					delete ISMPEPSig;
+					delete[] ISRevSig;
+					delete[] ISMPEPSig;
 
 					/* Reimposta la lunghezza */
 					WLen3 = ISSigLen;
@@ -1466,8 +1469,8 @@ int main(int argc, char * argv[])
 						}
 
 					/* Dealloca gli array MP/EP finestrati */
-					delete MPPFSig;
-					delete EPPFSig;
+					delete[] MPPFSig;
+					delete[] EPPFSig;
 				break;
 			}
 
@@ -1608,7 +1611,7 @@ int main(int argc, char * argv[])
 					}
 
 				/* Dealloca l'array per la convoluzione target */
-				delete PTTConv;
+				delete[] PTTConv;
 
 				/* Verifica se si deve salvare il filtro psicoacustico */
 				if (Cfg.PTFilterFile != NULL)
@@ -1669,7 +1672,7 @@ int main(int argc, char * argv[])
 					}
 
 				/* Dealloca il filtro target */
-				delete PTFilter;
+				delete[] PTFilter;
 
 				/* Finestratura finale filtro risultante */
 				if (Cfg.PTOutWindow > 0)
@@ -1712,7 +1715,7 @@ int main(int argc, char * argv[])
 					}
 
 				/* Dealloca e riassegna il filtro inverso */
-				delete ISRevOut;
+				delete[] ISRevOut;
 				ISRevOut = PTTConv;
 			}
 
@@ -1860,7 +1863,7 @@ int main(int argc, char * argv[])
 					}
 
 				/* Dealloca il segnale invertito */
-				delete ISRevOut;
+				delete[] ISRevOut;
 
 				/* Determina la lunghezza della componente dopo la finestratura */
 				if (Cfg.RTOutWindow > 0)
@@ -2084,7 +2087,7 @@ int main(int argc, char * argv[])
 						PSFilter[I] = MPSig[I];
 
 					/* Dealloca l'array deconvoluzione */
-					delete MPSig;
+					delete[] MPSig;
 				break;
 			}
 
@@ -2098,8 +2101,8 @@ int main(int argc, char * argv[])
 			}
 
 		/* Deallocazione array */
-		delete ISRevOut;
-		delete PSFilter;
+		delete[] ISRevOut;
+		delete[] PSFilter;
 
 		/* Determina la dimensione della finestra di uscita */
 		if (Cfg.PSOutWindow > 0)
@@ -2221,9 +2224,9 @@ int main(int argc, char * argv[])
 			}
 
 		/* Deallocazione array */
-		delete PSFilterFreqs;
-		delete PSFilterM;
-		delete PSFilterP;
+		delete[] PSFilterFreqs;
+		delete[] PSFilterM;
+		delete[] PSFilterP;
 
     /* Reimposta la lunghezza filtro */
     PSOutSigLen = WLen2;
@@ -2290,11 +2293,11 @@ int main(int argc, char * argv[])
 					}
 
 				/* Dealloca l'array deconvoluzione */
-				delete MPSig;
+				delete[] MPSig;
 			}
 
 		/* Deallocazione array */
-		delete PSOutSig;
+		delete[] PSOutSig;
 
 		/*********************************************************************************/
 		/* Convoluzione di test */
@@ -2406,18 +2409,18 @@ int main(int argc, char * argv[])
 					}
 
 				/* Dealloca gli array temporanei */
-				delete TCSig;
+				delete[] TCSig;
 			}
 
 		/* Dealloca gli array temporanei */
 		if (Cfg.TCOutFile != NULL || Cfg.PTType[0] != 'N')
-			delete OInSig;
+			delete[] OInSig;
 
 		/* Dealloca il filtro convoluzione test */
-		delete PSFilter;
+		delete[] PSFilter;
 
 		/* Libera la memoria della struttura di configurazione */
-		FreeCfgStruct(CfgParmsDef);
+		CfgFree(CfgParmsDef);
 		free(DRCFile);
 
 		/* Esecuzione completata */
