@@ -21,15 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
-		This program uses  also the FFT  routines from  Takuya Ooura and
-		the GNU Scientific  Library (GSL).  Many thanks  to Takuya Ooura
-		and the GSL developers for these efficient routines.
-
 ****************************************************************************/
 
 /* Opzioni di configurazione DRC */
@@ -41,231 +32,236 @@
 #include <string.h>
 #include <stdlib.h>
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 /* Opzioni di configurazione */
 CfgParmsType Cfg;
 
 /* Definizione struttura file di configurazione */
-cfgStruct CfgParmsDef[] =
+CfgParameter CfgParmsDef[] =
 	{
 		/* Base configuration */
-		{ (char *) "BCBaseDir",CFG_STRING,&Cfg.BCBaseDir },
-		{ (char *) "BCInFile",CFG_STRING,&Cfg.BCInFile },
-		{ (char *) "BCInFileType",CFG_STRING,&Cfg.BCInFileType },
-		{ (char *) "BCSampleRate",CFG_INT,&Cfg.BCSampleRate },
-		{ (char *) "BCImpulseCenterMode",CFG_STRING,&Cfg.BCImpulseCenterMode },
-		{ (char *) "BCImpulseCenter",CFG_INT,&Cfg.BCImpulseCenter },
-		{ (char *) "BCInitWindow",CFG_INT,&Cfg.BCInitWindow },
-		{ (char *) "BCPreWindowLen",CFG_INT,&Cfg.BCPreWindowLen },
-		{ (char *) "BCPreWindowGap",CFG_INT,&Cfg.BCPreWindowGap },
+		{ (char *) "BCBaseDir",CfgString,&Cfg.BCBaseDir },
+		{ (char *) "BCInFile",CfgString,&Cfg.BCInFile },
+		{ (char *) "BCInFileType",CfgString,&Cfg.BCInFileType },
+		{ (char *) "BCSampleRate",CfgInt,&Cfg.BCSampleRate },
+		{ (char *) "BCImpulseCenterMode",CfgString,&Cfg.BCImpulseCenterMode },
+		{ (char *) "BCImpulseCenter",CfgInt,&Cfg.BCImpulseCenter },
+		{ (char *) "BCInitWindow",CfgInt,&Cfg.BCInitWindow },
+		{ (char *) "BCPreWindowLen",CfgInt,&Cfg.BCPreWindowLen },
+		{ (char *) "BCPreWindowGap",CfgInt,&Cfg.BCPreWindowGap },
 		{ (char *) "BCNormFactor",DRCCfgFloat,&Cfg.BCNormFactor },
-		{ (char *) "BCNormType",CFG_STRING,&Cfg.BCNormType },
+		{ (char *) "BCNormType",CfgString,&Cfg.BCNormType },
 
     /* Mic correction stage */
-		{ (char *) "MCFilterType",CFG_STRING,&Cfg.MCFilterType },
-		{ (char *) "MCInterpolationType",CFG_STRING,&Cfg.MCInterpolationType },
-		{ (char *) "MCMultExponent",CFG_INT,&Cfg.MCMultExponent },
-		{ (char *) "MCFilterLen",CFG_INT,&Cfg.MCFilterLen },
-		{ (char *) "MCNumPoints",CFG_INT,&Cfg.MCNumPoints },
-		{ (char *) "MCPointsFile",CFG_STRING,&Cfg.MCPointsFile },
-		{ (char *) "MCMagType",CFG_STRING,&Cfg.MCMagType },
-		{ (char *) "MCFilterFile",CFG_STRING,&Cfg.MCFilterFile },
-		{ (char *) "MCFilterFileType",CFG_STRING,&Cfg.MCFilterFileType },
-		{ (char *) "MCOutWindow",CFG_INT,&Cfg.MCOutWindow },
+		{ (char *) "MCFilterType",CfgString,&Cfg.MCFilterType },
+		{ (char *) "MCInterpolationType",CfgString,&Cfg.MCInterpolationType },
+		{ (char *) "MCMultExponent",CfgInt,&Cfg.MCMultExponent },
+		{ (char *) "MCFilterLen",CfgInt,&Cfg.MCFilterLen },
+		{ (char *) "MCNumPoints",CfgInt,&Cfg.MCNumPoints },
+		{ (char *) "MCPointsFile",CfgString,&Cfg.MCPointsFile },
+		{ (char *) "MCMagType",CfgString,&Cfg.MCMagType },
+		{ (char *) "MCFilterFile",CfgString,&Cfg.MCFilterFile },
+		{ (char *) "MCFilterFileType",CfgString,&Cfg.MCFilterFileType },
+		{ (char *) "MCOutWindow",CfgInt,&Cfg.MCOutWindow },
 		{ (char *) "MCNormFactor",DRCCfgFloat,&Cfg.MCNormFactor },
-		{ (char *) "MCNormType",CFG_STRING,&Cfg.MCNormType },
-		{ (char *) "MCOutFile",CFG_STRING,&Cfg.MCOutFile },
-		{ (char *) "MCOutFileType",CFG_STRING,&Cfg.MCOutFileType },
+		{ (char *) "MCNormType",CfgString,&Cfg.MCNormType },
+		{ (char *) "MCOutFile",CfgString,&Cfg.MCOutFile },
+		{ (char *) "MCOutFileType",CfgString,&Cfg.MCOutFileType },
 
 		/* Base configuration dip limiting stage */
-		{ (char *) "BCDLType",CFG_STRING,&Cfg.BCDLType },
+		{ (char *) "BCDLType",CfgString,&Cfg.BCDLType },
 		{ (char *) "BCDLMinGain",DRCCfgFloat,&Cfg.BCDLMinGain },
 		{ (char *) "BCDLStartFreq",DRCCfgFloat,&Cfg.BCDLStartFreq },
 		{ (char *) "BCDLEndFreq",DRCCfgFloat,&Cfg.BCDLEndFreq },
 		{ (char *) "BCDLStart",DRCCfgFloat,&Cfg.BCDLStart },
-		{ (char *) "BCDLMultExponent",CFG_INT,&Cfg.BCDLMultExponent },
+		{ (char *) "BCDLMultExponent",CfgInt,&Cfg.BCDLMultExponent },
 
 		/* Homomorphic Deconvolution */
-		{ (char *) "HDMultExponent",CFG_INT,&Cfg.HDMultExponent },
+		{ (char *) "HDMultExponent",CfgInt,&Cfg.HDMultExponent },
 		{ (char *) "HDMPNormFactor",DRCCfgFloat,&Cfg.HDMPNormFactor },
-		{ (char *) "HDMPNormType",CFG_STRING,&Cfg.HDMPNormType },
-		{ (char *) "HDMPOutFile",CFG_STRING,&Cfg.HDMPOutFile },
-		{ (char *) "HDMPOutFileType",CFG_STRING,&Cfg.HDMPOutFileType },
+		{ (char *) "HDMPNormType",CfgString,&Cfg.HDMPNormType },
+		{ (char *) "HDMPOutFile",CfgString,&Cfg.HDMPOutFile },
+		{ (char *) "HDMPOutFileType",CfgString,&Cfg.HDMPOutFileType },
 		{ (char *) "HDEPNormFactor",DRCCfgFloat,&Cfg.HDEPNormFactor },
-		{ (char *) "HDEPNormType",CFG_STRING,&Cfg.HDEPNormType },
-		{ (char *) "HDEPOutFile",CFG_STRING,&Cfg.HDEPOutFile },
-		{ (char *) "HDEPOutFileType",CFG_STRING,&Cfg.HDEPOutFileType },
+		{ (char *) "HDEPNormType",CfgString,&Cfg.HDEPNormType },
+		{ (char *) "HDEPOutFile",CfgString,&Cfg.HDEPOutFile },
+		{ (char *) "HDEPOutFileType",CfgString,&Cfg.HDEPOutFileType },
 
 		/* Minimum phase prefiltering stage */
-		{ (char *) "MPPrefilterType",CFG_STRING,&Cfg.MPPrefilterType },
-		{ (char *) "MPPrefilterFctn",CFG_STRING,&Cfg.MPPrefilterFctn },
-		{ (char *) "MPWindowGap",CFG_INT,&Cfg.MPWindowGap },
-		{ (char *) "MPLowerWindow",CFG_INT,&Cfg.MPLowerWindow },
-		{ (char *) "MPUpperWindow",CFG_INT,&Cfg.MPUpperWindow },
+		{ (char *) "MPPrefilterType",CfgString,&Cfg.MPPrefilterType },
+		{ (char *) "MPPrefilterFctn",CfgString,&Cfg.MPPrefilterFctn },
+		{ (char *) "MPWindowGap",CfgInt,&Cfg.MPWindowGap },
+		{ (char *) "MPLowerWindow",CfgInt,&Cfg.MPLowerWindow },
+		{ (char *) "MPUpperWindow",CfgInt,&Cfg.MPUpperWindow },
 		{ (char *) "MPStartFreq",DRCCfgFloat,&Cfg.MPStartFreq },
 		{ (char *) "MPEndFreq",DRCCfgFloat,&Cfg.MPEndFreq },
 		{ (char *) "MPWindowExponent",DRCCfgFloat,&Cfg.MPWindowExponent },
-		{ (char *) "MPFilterLen",CFG_INT,&Cfg.MPFilterLen },
+		{ (char *) "MPFilterLen",CfgInt,&Cfg.MPFilterLen },
 		{ (char *) "MPFSharpness",DRCCfgFloat,&Cfg.MPFSharpness },
-		{ (char *) "MPBandSplit",CFG_INT,&Cfg.MPBandSplit },
-		{ (char *) "MPHDRecover",CFG_STRING,&Cfg.MPHDRecover },
-		{ (char *) "MPEPPreserve",CFG_STRING,&Cfg.MPEPPreserve },
-		{ (char *) "MPHDMultExponent",CFG_INT,&Cfg.MPHDMultExponent },
-		{ (char *) "MPPFFinalWindow",CFG_INT,&Cfg.MPPFFinalWindow },
+		{ (char *) "MPBandSplit",CfgInt,&Cfg.MPBandSplit },
+		{ (char *) "MPHDRecover",CfgString,&Cfg.MPHDRecover },
+		{ (char *) "MPEPPreserve",CfgString,&Cfg.MPEPPreserve },
+		{ (char *) "MPHDMultExponent",CfgInt,&Cfg.MPHDMultExponent },
+		{ (char *) "MPPFFinalWindow",CfgInt,&Cfg.MPPFFinalWindow },
 		{ (char *) "MPPFNormFactor",DRCCfgFloat,&Cfg.MPPFNormFactor },
-		{ (char *) "MPPFNormType",CFG_STRING,&Cfg.MPPFNormType },
-		{ (char *) "MPPFOutFile",CFG_STRING,&Cfg.MPPFOutFile },
-		{ (char *) "MPPFOutFileType",CFG_STRING,&Cfg.MPPFOutFileType },
+		{ (char *) "MPPFNormType",CfgString,&Cfg.MPPFNormType },
+		{ (char *) "MPPFOutFile",CfgString,&Cfg.MPPFOutFile },
+		{ (char *) "MPPFOutFileType",CfgString,&Cfg.MPPFOutFileType },
 
 		/* Dip limiting stage */
-		{ (char *) "DLType",CFG_STRING,&Cfg.DLType },
+		{ (char *) "DLType",CfgString,&Cfg.DLType },
 		{ (char *) "DLMinGain",DRCCfgFloat,&Cfg.DLMinGain },
 		{ (char *) "DLStartFreq",DRCCfgFloat,&Cfg.DLStartFreq },
 		{ (char *) "DLEndFreq",DRCCfgFloat,&Cfg.DLEndFreq },
 		{ (char *) "DLStart",DRCCfgFloat,&Cfg.DLStart },
-		{ (char *) "DLMultExponent",CFG_INT,&Cfg.DLMultExponent },
+		{ (char *) "DLMultExponent",CfgInt,&Cfg.DLMultExponent },
 
 		/* Excess fase phase prefiltering stage */
-		{ (char *) "EPPrefilterType",CFG_STRING,&Cfg.EPPrefilterType },
-		{ (char *) "EPPrefilterFctn",CFG_STRING,&Cfg.EPPrefilterFctn },
-		{ (char *) "EPWindowGap",CFG_INT,&Cfg.EPWindowGap },
-		{ (char *) "EPLowerWindow",CFG_INT,&Cfg.EPLowerWindow },
-		{ (char *) "EPUpperWindow",CFG_INT,&Cfg.EPUpperWindow },
+		{ (char *) "EPPrefilterType",CfgString,&Cfg.EPPrefilterType },
+		{ (char *) "EPPrefilterFctn",CfgString,&Cfg.EPPrefilterFctn },
+		{ (char *) "EPWindowGap",CfgInt,&Cfg.EPWindowGap },
+		{ (char *) "EPLowerWindow",CfgInt,&Cfg.EPLowerWindow },
+		{ (char *) "EPUpperWindow",CfgInt,&Cfg.EPUpperWindow },
 		{ (char *) "EPStartFreq",DRCCfgFloat,&Cfg.EPStartFreq },
 		{ (char *) "EPEndFreq",DRCCfgFloat,&Cfg.EPEndFreq },
 		{ (char *) "EPWindowExponent",DRCCfgFloat,&Cfg.EPWindowExponent },
-		{ (char *) "EPFilterLen",CFG_INT,&Cfg.EPFilterLen },
+		{ (char *) "EPFilterLen",CfgInt,&Cfg.EPFilterLen },
 		{ (char *) "EPFSharpness",DRCCfgFloat,&Cfg.EPFSharpness },
-		{ (char *) "EPBandSplit",CFG_INT,&Cfg.EPBandSplit },
+		{ (char *) "EPBandSplit",CfgInt,&Cfg.EPBandSplit },
 		{ (char *) "EPPFFlatGain",DRCCfgFloat,&Cfg.EPPFFlatGain },
 		{ (char *) "EPPFOGainFactor",DRCCfgFloat,&Cfg.EPPFOGainFactor },
-		{ (char *) "EPPFFlatType",CFG_STRING,&Cfg.EPPFFlatType },
-		{ (char *) "EPPFFGMultExponent",CFG_INT,&Cfg.EPPFFGMultExponent },
-		{ (char *) "EPPFFinalWindow",CFG_INT,&Cfg.EPPFFinalWindow },
+		{ (char *) "EPPFFlatType",CfgString,&Cfg.EPPFFlatType },
+		{ (char *) "EPPFFGMultExponent",CfgInt,&Cfg.EPPFFGMultExponent },
+		{ (char *) "EPPFFinalWindow",CfgInt,&Cfg.EPPFFinalWindow },
 		{ (char *) "EPPFNormFactor",DRCCfgFloat,&Cfg.EPPFNormFactor },
-		{ (char *) "EPPFNormType",CFG_STRING,&Cfg.EPPFNormType },
-		{ (char *) "EPPFOutFile",CFG_STRING,&Cfg.EPPFOutFile },
-		{ (char *) "EPPFOutFileType",CFG_STRING,&Cfg.EPPFOutFileType },
+		{ (char *) "EPPFNormType",CfgString,&Cfg.EPPFNormType },
+		{ (char *) "EPPFOutFile",CfgString,&Cfg.EPPFOutFile },
+		{ (char *) "EPPFOutFileType",CfgString,&Cfg.EPPFOutFileType },
 
 		/* Prefiltering completion stage */
-		{ (char *) "PCOutWindow",CFG_INT,&Cfg.PCOutWindow },
+		{ (char *) "PCOutWindow",CfgInt,&Cfg.PCOutWindow },
 		{ (char *) "PCNormFactor",DRCCfgFloat,&Cfg.PCNormFactor },
-		{ (char *) "PCNormType",CFG_STRING,&Cfg.PCNormType },
-		{ (char *) "PCOutFile",CFG_STRING,&Cfg.PCOutFile },
-		{ (char *) "PCOutFileType",CFG_STRING,&Cfg.PCOutFileType },
+		{ (char *) "PCNormType",CfgString,&Cfg.PCNormType },
+		{ (char *) "PCOutFile",CfgString,&Cfg.PCOutFile },
+		{ (char *) "PCOutFileType",CfgString,&Cfg.PCOutFileType },
 
 		/* Inversion stage */
-		{ (char *) "ISType",CFG_STRING,&Cfg.ISType },
-		{ (char *) "ISPETType",CFG_STRING,&Cfg.ISPETType },
-		{ (char *) "ISPrefilterFctn",CFG_STRING,&Cfg.ISPrefilterFctn },
-		{ (char *) "ISPELowerWindow",CFG_INT,&Cfg.ISPELowerWindow },
-		{ (char *) "ISPEUpperWindow",CFG_INT,&Cfg.ISPEUpperWindow },
-		{ (char *) "ISPEStartFreq",CFG_INT,&Cfg.ISPEStartFreq },
-		{ (char *) "ISPEEndFreq",CFG_INT,&Cfg.ISPEEndFreq },
-		{ (char *) "ISPEFilterLen",CFG_INT,&Cfg.ISPEFilterLen },
+		{ (char *) "ISType",CfgString,&Cfg.ISType },
+		{ (char *) "ISPETType",CfgString,&Cfg.ISPETType },
+		{ (char *) "ISPrefilterFctn",CfgString,&Cfg.ISPrefilterFctn },
+		{ (char *) "ISPELowerWindow",CfgInt,&Cfg.ISPELowerWindow },
+		{ (char *) "ISPEUpperWindow",CfgInt,&Cfg.ISPEUpperWindow },
+		{ (char *) "ISPEStartFreq",CfgInt,&Cfg.ISPEStartFreq },
+		{ (char *) "ISPEEndFreq",CfgInt,&Cfg.ISPEEndFreq },
+		{ (char *) "ISPEFilterLen",CfgInt,&Cfg.ISPEFilterLen },
 		{ (char *) "ISPEFSharpness",DRCCfgFloat,&Cfg.ISPEFSharpness },
-		{ (char *) "ISPEBandSplit",CFG_INT,&Cfg.ISPEBandSplit },
+		{ (char *) "ISPEBandSplit",CfgInt,&Cfg.ISPEBandSplit },
 		{ (char *) "ISPEWindowExponent",DRCCfgFloat,&Cfg.ISPEWindowExponent },
 		{ (char *) "ISPEOGainFactor",DRCCfgFloat,&Cfg.ISPEOGainFactor },
-		{ (char *) "ISSMPMultExponent",CFG_INT,&Cfg.ISSMPMultExponent },
-		{ (char *) "ISOutWindow",CFG_INT,&Cfg.ISOutWindow },
+		{ (char *) "ISSMPMultExponent",CfgInt,&Cfg.ISSMPMultExponent },
+		{ (char *) "ISOutWindow",CfgInt,&Cfg.ISOutWindow },
 		{ (char *) "ISNormFactor",DRCCfgFloat,&Cfg.ISNormFactor },
-		{ (char *) "ISNormType",CFG_STRING,&Cfg.ISNormType },
-		{ (char *) "ISOutFile",CFG_STRING,&Cfg.ISOutFile },
-		{ (char *) "ISOutFileType",CFG_STRING,&Cfg.ISOutFileType },
+		{ (char *) "ISNormType",CfgString,&Cfg.ISNormType },
+		{ (char *) "ISOutFile",CfgString,&Cfg.ISOutFile },
+		{ (char *) "ISOutFileType",CfgString,&Cfg.ISOutFileType },
 
 		/* Psychoacoustic target stage */
-		{ (char *) "PTType",CFG_STRING,&Cfg.PTType },
-		{ (char *) "PTReferenceWindow",CFG_INT,&Cfg.PTReferenceWindow },
-		{ (char *) "PTDLType",CFG_STRING,&Cfg.PTDLType },
+		{ (char *) "PTType",CfgString,&Cfg.PTType },
+		{ (char *) "PTReferenceWindow",CfgInt,&Cfg.PTReferenceWindow },
+		{ (char *) "PTDLType",CfgString,&Cfg.PTDLType },
 		{ (char *) "PTDLMinGain",DRCCfgFloat,&Cfg.PTDLMinGain },
 		{ (char *) "PTDLStart",DRCCfgFloat,&Cfg.PTDLStart },
 		{ (char *) "PTDLStartFreq",DRCCfgFloat,&Cfg.PTDLStartFreq },
 		{ (char *) "PTDLEndFreq",DRCCfgFloat,&Cfg.PTDLEndFreq },
-		{ (char *) "PTDLMultExponent",CFG_INT,&Cfg.PTDLMultExponent },
+		{ (char *) "PTDLMultExponent",CfgInt,&Cfg.PTDLMultExponent },
 		{ (char *) "PTBandWidth",DRCCfgFloat,&Cfg.PTBandWidth },
 		{ (char *) "PTPeakDetectionStrength",DRCCfgFloat,&Cfg.PTPeakDetectionStrength },
-		{ (char *) "PTMultExponent",CFG_INT,&Cfg.PTMultExponent },
-		{ (char *) "PTFilterLen",CFG_INT,&Cfg.PTFilterLen },
-		{ (char *) "PTFilterFile",CFG_STRING,&Cfg.PTFilterFile },
-		{ (char *) "PTFilterFileType",CFG_STRING,&Cfg.PTFilterFileType },
+		{ (char *) "PTMultExponent",CfgInt,&Cfg.PTMultExponent },
+		{ (char *) "PTFilterLen",CfgInt,&Cfg.PTFilterLen },
+		{ (char *) "PTFilterFile",CfgString,&Cfg.PTFilterFile },
+		{ (char *) "PTFilterFileType",CfgString,&Cfg.PTFilterFileType },
 		{ (char *) "PTNormFactor",DRCCfgFloat,&Cfg.PTNormFactor },
-		{ (char *) "PTNormType",CFG_STRING,&Cfg.PTNormType },
-		{ (char *) "PTOutFile",CFG_STRING,&Cfg.PTOutFile },
-		{ (char *) "PTOutFileType",CFG_STRING,&Cfg.PTOutFileType },
-		{ (char *) "PTOutWindow",CFG_INT,&Cfg.PTOutWindow },
+		{ (char *) "PTNormType",CfgString,&Cfg.PTNormType },
+		{ (char *) "PTOutFile",CfgString,&Cfg.PTOutFile },
+		{ (char *) "PTOutFileType",CfgString,&Cfg.PTOutFileType },
+		{ (char *) "PTOutWindow",CfgInt,&Cfg.PTOutWindow },
 
 		/* Peak limiting stage */
-		{ (char *) "PLType",CFG_STRING,&Cfg.PLType },
+		{ (char *) "PLType",CfgString,&Cfg.PLType },
 		{ (char *) "PLMaxGain",DRCCfgFloat,&Cfg.PLMaxGain },
 		{ (char *) "PLStart",DRCCfgFloat,&Cfg.PLStart },
 		{ (char *) "PLStartFreq",DRCCfgFloat,&Cfg.PLStartFreq },
 		{ (char *) "PLEndFreq",DRCCfgFloat,&Cfg.PLEndFreq },
-		{ (char *) "PLMultExponent",CFG_INT,&Cfg.PLMultExponent },
-		{ (char *) "PLOutWindow",CFG_INT,&Cfg.PLOutWindow },
+		{ (char *) "PLMultExponent",CfgInt,&Cfg.PLMultExponent },
+		{ (char *) "PLOutWindow",CfgInt,&Cfg.PLOutWindow },
 		{ (char *) "PLNormFactor",DRCCfgFloat,&Cfg.PLNormFactor },
-		{ (char *) "PLNormType",CFG_STRING,&Cfg.PLNormType },
-		{ (char *) "PLOutFile",CFG_STRING,&Cfg.PLOutFile },
-		{ (char *) "PLOutFileType",CFG_STRING,&Cfg.PLOutFileType },
+		{ (char *) "PLNormType",CfgString,&Cfg.PLNormType },
+		{ (char *) "PLOutFile",CfgString,&Cfg.PLOutFile },
+		{ (char *) "PLOutFileType",CfgString,&Cfg.PLOutFileType },
 
 		/* Ringing truncation stage */
-		{ (char *) "RTType",CFG_STRING,&Cfg.RTType },
-		{ (char *) "RTPrefilterFctn",CFG_STRING,&Cfg.RTPrefilterFctn },
-		{ (char *) "RTWindowGap",CFG_INT,&Cfg.RTWindowGap },
-		{ (char *) "RTLowerWindow",CFG_INT,&Cfg.RTLowerWindow },
-		{ (char *) "RTUpperWindow",CFG_INT,&Cfg.RTUpperWindow },
+		{ (char *) "RTType",CfgString,&Cfg.RTType },
+		{ (char *) "RTPrefilterFctn",CfgString,&Cfg.RTPrefilterFctn },
+		{ (char *) "RTWindowGap",CfgInt,&Cfg.RTWindowGap },
+		{ (char *) "RTLowerWindow",CfgInt,&Cfg.RTLowerWindow },
+		{ (char *) "RTUpperWindow",CfgInt,&Cfg.RTUpperWindow },
 		{ (char *) "RTStartFreq",DRCCfgFloat,&Cfg.RTStartFreq },
 		{ (char *) "RTEndFreq",DRCCfgFloat,&Cfg.RTEndFreq },
 		{ (char *) "RTWindowExponent",DRCCfgFloat,&Cfg.RTWindowExponent },
-		{ (char *) "RTFilterLen",CFG_INT,&Cfg.RTFilterLen },
+		{ (char *) "RTFilterLen",CfgInt,&Cfg.RTFilterLen },
 		{ (char *) "RTFSharpness",DRCCfgFloat,&Cfg.RTFSharpness },
-		{ (char *) "RTBandSplit",CFG_INT,&Cfg.RTBandSplit },
-		{ (char *) "RTOutWindow",CFG_INT,&Cfg.RTOutWindow },
+		{ (char *) "RTBandSplit",CfgInt,&Cfg.RTBandSplit },
+		{ (char *) "RTOutWindow",CfgInt,&Cfg.RTOutWindow },
 		{ (char *) "RTNormFactor",DRCCfgFloat,&Cfg.RTNormFactor },
-		{ (char *) "RTNormType",CFG_STRING,&Cfg.RTNormType },
-		{ (char *) "RTOutFile",CFG_STRING,&Cfg.RTOutFile },
-		{ (char *) "RTOutFileType",CFG_STRING,&Cfg.RTOutFileType },
+		{ (char *) "RTNormType",CfgString,&Cfg.RTNormType },
+		{ (char *) "RTOutFile",CfgString,&Cfg.RTOutFile },
+		{ (char *) "RTOutFileType",CfgString,&Cfg.RTOutFileType },
 
 		/* Target response stage */
-		{ (char *) "PSFilterType",CFG_STRING,&Cfg.PSFilterType },
-		{ (char *) "PSInterpolationType",CFG_STRING,&Cfg.PSInterpolationType },
-		{ (char *) "PSMultExponent",CFG_INT,&Cfg.PSMultExponent },
-		{ (char *) "PSFilterLen",CFG_INT,&Cfg.PSFilterLen },
-		{ (char *) "PSNumPoints",CFG_INT,&Cfg.PSNumPoints },
-		{ (char *) "PSPointsFile",CFG_STRING,&Cfg.PSPointsFile },
-		{ (char *) "PSMagType",CFG_STRING,&Cfg.PSMagType },
-		{ (char *) "PSOutWindow",CFG_INT,&Cfg.PSOutWindow },
+		{ (char *) "PSFilterType",CfgString,&Cfg.PSFilterType },
+		{ (char *) "PSInterpolationType",CfgString,&Cfg.PSInterpolationType },
+		{ (char *) "PSMultExponent",CfgInt,&Cfg.PSMultExponent },
+		{ (char *) "PSFilterLen",CfgInt,&Cfg.PSFilterLen },
+		{ (char *) "PSNumPoints",CfgInt,&Cfg.PSNumPoints },
+		{ (char *) "PSPointsFile",CfgString,&Cfg.PSPointsFile },
+		{ (char *) "PSMagType",CfgString,&Cfg.PSMagType },
+		{ (char *) "PSOutWindow",CfgInt,&Cfg.PSOutWindow },
 		{ (char *) "PSNormFactor",DRCCfgFloat,&Cfg.PSNormFactor },
-		{ (char *) "PSNormType",CFG_STRING,&Cfg.PSNormType },
-		{ (char *) "PSOutFile",CFG_STRING,&Cfg.PSOutFile },
-		{ (char *) "PSOutFileType",CFG_STRING,&Cfg.PSOutFileType },
+		{ (char *) "PSNormType",CfgString,&Cfg.PSNormType },
+		{ (char *) "PSOutFile",CfgString,&Cfg.PSOutFile },
+		{ (char *) "PSOutFileType",CfgString,&Cfg.PSOutFileType },
 
 		/* Minimum phase filter extraction stage */
-		{ (char *) "MSMultExponent",CFG_INT,&Cfg.MSMultExponent },
-		{ (char *) "MSOutWindow",CFG_INT,&Cfg.MSOutWindow },
-		{ (char *) "MSFilterDelay",CFG_INT,&Cfg.MSFilterDelay },
+		{ (char *) "MSMultExponent",CfgInt,&Cfg.MSMultExponent },
+		{ (char *) "MSOutWindow",CfgInt,&Cfg.MSOutWindow },
+		{ (char *) "MSFilterDelay",CfgInt,&Cfg.MSFilterDelay },
 		{ (char *) "MSNormFactor",DRCCfgFloat,&Cfg.MSNormFactor },
-		{ (char *) "MSNormType",CFG_STRING,&Cfg.MSNormType },
-		{ (char *) "MSOutFile",CFG_STRING,&Cfg.MSOutFile },
-		{ (char *) "MSOutFileType",CFG_STRING,&Cfg.MSOutFileType },
+		{ (char *) "MSNormType",CfgString,&Cfg.MSNormType },
+		{ (char *) "MSOutFile",CfgString,&Cfg.MSOutFile },
+		{ (char *) "MSOutFileType",CfgString,&Cfg.MSOutFileType },
 
 		/* Test convolution stage */
 		{ (char *) "TCNormFactor",DRCCfgFloat,&Cfg.TCNormFactor },
-		{ (char *) "TCNormType",CFG_STRING,&Cfg.TCNormType },
-		{ (char *) "TCOutFile",CFG_STRING,&Cfg.TCOutFile },
-		{ (char *) "TCOutFileType",CFG_STRING,&Cfg.TCOutFileType },
-		{ (char *) "TCOWFile",CFG_STRING,&Cfg.TCOWFile },
-		{ (char *) "TCOWFileType",CFG_STRING,&Cfg.TCOWFileType },
+		{ (char *) "TCNormType",CfgString,&Cfg.TCNormType },
+		{ (char *) "TCOutFile",CfgString,&Cfg.TCOutFile },
+		{ (char *) "TCOutFileType",CfgString,&Cfg.TCOutFileType },
+		{ (char *) "TCOWFile",CfgString,&Cfg.TCOWFile },
+		{ (char *) "TCOWFileType",CfgString,&Cfg.TCOWFileType },
 		{ (char *) "TCOWNormFactor",DRCCfgFloat,&Cfg.TCOWNormFactor },
-		{ (char *) "TCOWNormType",CFG_STRING,&Cfg.TCOWNormType },
-		{ (char *) "TCOWSkip",CFG_INT,&Cfg.TCOWSkip },
-		{ (char *) "TCOWPrewindow",CFG_INT,&Cfg.TCOWPrewindow },
-		{ (char *) "TCOWLength",CFG_INT,&Cfg.TCOWLength },
+		{ (char *) "TCOWNormType",CfgString,&Cfg.TCOWNormType },
+		{ (char *) "TCOWSkip",CfgInt,&Cfg.TCOWSkip },
+		{ (char *) "TCOWPrewindow",CfgInt,&Cfg.TCOWPrewindow },
+		{ (char *) "TCOWLength",CfgInt,&Cfg.TCOWLength },
 
 		/* Chiusura lista parametri */
-		{NULL, CFG_END, NULL}
+		{NULL, CfgEnd, NULL}
 	};
 
-/* Elenco dei parametri di configurazione che richiedo gestione della
+/* Elenco dei parametri di configurazione che richiedono gestione della
 directory base */
 static const char * BaseDirParmsList[] =
 	{
@@ -302,12 +298,12 @@ static char * StrJoin(const char * S1, const char * S2)
 	}
 
 /* Ritorna la posizione del parametro indicato */
-static int GetCfgParmPos(const cfgStruct * CfgParmsDef, const char * ParmName)
+static int GetCfgParmPos(const CfgParameter * CfgParmsDef, const char * ParmName)
 	{
 		int P = 0;
-		while (CfgParmsDef[P].type != CFG_END)
+		while (CfgParmsDef[P].PType != CfgEnd)
 			{
-				if (strcmp(CfgParmsDef[P].parameterName,ParmName) == 0)
+				if (strcmp(CfgParmsDef[P].PName,ParmName) == 0)
 					return P;
 				P++;
 			}
@@ -315,7 +311,7 @@ static int GetCfgParmPos(const cfgStruct * CfgParmsDef, const char * ParmName)
 	}
 
 /* Impostazione directory base di lavoro */
-int SetupDRCCfgBaseDir(CfgParmsType * DRCCfg, const cfgStruct * CfgParmsDef,
+int SetupDRCCfgBaseDir(CfgParmsType * DRCCfg, const CfgParameter * CfgParmsDef,
 	const CmdLineType * OptData)
 	{
 		/* Parametro corrente */
@@ -344,21 +340,21 @@ int SetupDRCCfgBaseDir(CfgParmsType * DRCCfg, const cfgStruct * CfgParmsDef,
 				a linea di comando */
 				if ((OptData->ParmSet[P] == False ||
 					OptData->ParmSet[BCBaseDirParmPos] == True) &&
-					(*((void **) CfgParmsDef[P].value) != NULL))
+					(*((void **) CfgParmsDef[P].PValue) != NULL))
 					{
 						/* Aggiunge la directory base al parametro */
 						S = StrJoin(DRCCfg->BCBaseDir,
-							(char *) (* ((void **) CfgParmsDef[P].value)));
+							(char *) (* ((void **) CfgParmsDef[P].PValue)));
 
 						/* Verifica che la concatenazione sia riuscita */
 						if (S == NULL)
 							return 1;
 
 						/* Dealloca la stringa precedente */
-						free(*((void **) CfgParmsDef[P].value));
+						free(*((void **) CfgParmsDef[P].PValue));
 
 						/* Sostituisce la stringa precedente */
-						*((void **) CfgParmsDef[P].value) = (void *) S;
+						*((void **) CfgParmsDef[P].PValue) = (void *) S;
 					}
 
 				/* Passa al parametro successivo */
@@ -835,6 +831,11 @@ int CheckDRCCfg(const CfgParmsType * DRCCfg)
 				sputs("IS->ISPrefilterFctn: Invalid ISPrefilterFctn supplied.");
 				return 1;
 			}
+		if (DRCCfg->ISPEUpperWindow >= DRCCfg->ISPELowerWindow)
+			{
+				sputs("IS->ISPEUpperWindow: ISPELowerWindow must be greater than ISPEUpperWindow.");
+				return 1;
+			}
 		if (DRCCfg->ISPEFSharpness <= (DLReal) 0.0)
 			{
 				sputs("IS->ISPEFSharpness: ISPEFSharpness must be greater than 0.");
