@@ -21,15 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
-		This program uses  also the FFT  routines from  Takuya Ooura and
-		the GNU Scientific  Library (GSL).  Many thanks  to Takuya Ooura
-		and the GSL developers for these efficient routines.
-
 ****************************************************************************/
 
 /* Opzioni di configurazione DRC */
@@ -284,12 +275,12 @@
 	extern CfgParmsType Cfg;
 
 	/* Definizione struttura file di configurazione */
-	extern cfgStruct CfgParmsDef[];
+	extern CfgParameter CfgParmsDef[];
 
 	/* Controllo validit parametri di configurazione */
 	int CheckDRCCfg(const CfgParmsType * DRCCfg);
 
 	/* Impostazione directory base di lavoro */
-	int SetupDRCCfgBaseDir(CfgParmsType * DRCCfg, const cfgStruct * CfgParmsDef,
+	int SetupDRCCfgBaseDir(CfgParmsType * DRCCfg, const CfgParameter * CfgParmsDef,
 		const CmdLineType * OptData);
 #endif
