@@ -21,11 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
 ****************************************************************************/
 
 /****************************************************************************
@@ -42,6 +37,11 @@
 #include "spline.h"
 #include <stddef.h>
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 void LowPassFir(DLReal * Filter,unsigned int Order,DLReal Freq)
   {
     unsigned int I,J,K;
@@ -50,24 +50,26 @@ void LowPassFir(DLReal * Filter,unsigned int Order,DLReal Freq)
     DLReal FV;
 
     if (Order > 1)
-      if (Order%2 == 0)
-        for(I = 1,J = HalfOrder - 1,K = HalfOrder; I <= HalfOrder;I++,J--,K++)
-          {
-            FV = (DLReal) (I-((DLReal) 0.5));
-            FV = (DLReal) (DLSin(FV*C)/(FV*((DLReal) M_PI)));
-            Filter[J] = FV;
-            Filter[K] = FV;
-          }
-      else
-        {
-          for(I = 1,J = HalfOrder - 1,K = HalfOrder + 1; I <= HalfOrder;I++,J--,K++)
-            {
-              FV = (DLReal) (DLSin(I*C)/(I*((DLReal) M_PI)));
-              Filter[J] = FV;
-              Filter[K] = FV;
-            }
-          Filter[HalfOrder] = Freq;
-        }
+			{
+				if (Order%2 == 0)
+					for(I = 1,J = HalfOrder - 1,K = HalfOrder; I <= HalfOrder;I++,J--,K++)
+						{
+							FV = (DLReal) (I-((DLReal) 0.5));
+							FV = (DLReal) (DLSin(FV*C)/(FV*((DLReal) M_PI)));
+							Filter[J] = FV;
+							Filter[K] = FV;
+						}
+				else
+					{
+						for(I = 1,J = HalfOrder - 1,K = HalfOrder + 1; I <= HalfOrder;I++,J--,K++)
+							{
+								FV = (DLReal) (DLSin(I*C)/(I*((DLReal) M_PI)));
+								Filter[J] = FV;
+								Filter[K] = FV;
+							}
+						Filter[HalfOrder] = Freq;
+					}
+			}
   }
 
 void HighPassFir(DLReal * Filter,unsigned int Order,DLReal Freq)
@@ -100,25 +102,27 @@ void BandPassFir(DLReal * Filter,unsigned int Order,DLReal Low,DLReal High)
     DLReal D = (DLReal) (M_PI*(High-Low)/2), S = (DLReal) (M_PI*(High+Low)/2);
 
     if (Order > 1)
-      if (Order%2 == 0)
-				{
-					for(I = 1;I <= HalfOrder;I++)
-						{
-							Filter[HalfOrder-I] = (DLReal) ((2 / M_PI)*DLSin((I-0.5)*D)*
-								DLCos((I-0.5)*S)/(I-0.5));
-							Filter[HalfOrder+I-1] = Filter[HalfOrder-I];
-						}
-				}
-      else
-        {
-          for(I = 1;I <= HalfOrder;I++)
-            {
-              Filter[HalfOrder-I] = (DLReal) ((2 / M_PI)*DLSin(I*D)*
-                DLCos(I*S)/I);
-              Filter[HalfOrder+I] = Filter[HalfOrder-I];
-            }
-          Filter[HalfOrder] = (High-Low);
-        }
+			{
+				if (Order%2 == 0)
+					{
+						for(I = 1;I <= HalfOrder;I++)
+							{
+								Filter[HalfOrder-I] = (DLReal) ((2 / M_PI)*DLSin((I-0.5)*D)*
+									DLCos((I-0.5)*S)/(I-0.5));
+								Filter[HalfOrder+I-1] = Filter[HalfOrder-I];
+							}
+					}
+				else
+					{
+						for(I = 1;I <= HalfOrder;I++)
+							{
+								Filter[HalfOrder-I] = (DLReal) ((2 / M_PI)*DLSin(I*D)*
+									DLCos(I*S)/I);
+								Filter[HalfOrder+I] = Filter[HalfOrder-I];
+							}
+						Filter[HalfOrder] = (High-Low);
+					}
+			}
   }
 
 void BandStopFir(DLReal * Filter,unsigned int Order,DLReal Low,DLReal High)
@@ -206,7 +210,7 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
 
 		if ((Hf = new DLReal[HtSize]) == NULL)
 			{
-				delete(Ht);
+				delete[](Ht);
 				return(False);
 			}
 
@@ -223,23 +227,23 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
 					/* Alloca gli array temporanei rimappatura logaritmica */
 					if ((LF = new DLReal[Np]) == NULL)
 						{
-							delete(Ht);
-							delete(Hf);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 					if ((LM = new DLReal[Np]) == NULL)
 						{
-							delete(LF);
-							delete(Ht);
-							delete(Hf);
+							delete[](LF);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 					if ((LP = new DLReal[Np]) == NULL)
 						{
-							delete(LM);
-							delete(LF);
-							delete(Ht);
-							delete(Hf);
+							delete[](LM);
+							delete[](LF);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 
@@ -260,25 +264,25 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
 
 					if (CSLCASplineValue(LF,LM,LP,Np,&Hf[1],HtSize-1,&Ht[1],CSLLinear,CSLLogXLogY) == False)
 						{
-							delete(LP);
-							delete(LM);
-							delete(LF);
-							delete(Ht);
-							delete(Hf);
+							delete[](LP);
+							delete[](LM);
+							delete[](LF);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 
 					/* Dealloca gli array temporanei rimappatura logaritmica */
-					delete(LP);
-					delete(LM);
-					delete(LF);
+					delete[](LP);
+					delete[](LM);
+					delete[](LF);
 				break;
 
 				case SplineLinear:
 					if (CSLCASplineValue(F,M,P,Np,Hf,HtSize,Ht,CSLBSpline,CSLLinXLinY) == False)
 						{
-							delete(Ht);
-							delete(Hf);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 				break;
@@ -287,23 +291,23 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
 					/* Alloca gli array temporanei rimappatura logaritmica */
 					if ((LF = new DLReal[Np]) == NULL)
 						{
-							delete(Ht);
-							delete(Hf);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 					if ((LM = new DLReal[Np]) == NULL)
 						{
-							delete(LF);
-							delete(Ht);
-							delete(Hf);
+							delete[](LF);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 					if ((LP = new DLReal[Np]) == NULL)
 						{
-							delete(LM);
-							delete(LF);
-							delete(Ht);
-							delete(Hf);
+							delete[](LM);
+							delete[](LF);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 
@@ -324,25 +328,25 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
 
 					if (CSLCASplineValue(LF,LM,LP,Np,&Hf[1],HtSize-1,&Ht[1],CSLBSpline,CSLLogXLogY) == False)
 						{
-							delete(LP);
-							delete(LM);
-							delete(LF);
-							delete(Ht);
-							delete(Hf);
+							delete[](LP);
+							delete[](LM);
+							delete[](LF);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 
 					/* Dealloca gli array temporanei rimappatura logaritmica */
-					delete(LP);
-					delete(LM);
-					delete(LF);
+					delete[](LP);
+					delete[](LM);
+					delete[](LF);
 				break;
 
 				case PCHIPLinear:
 					if (CSLCASplineValue(F,M,P,Np,Hf,HtSize,Ht,CSLHSSpline,CSLLinXLinY) == False)
 						{
-							delete(Ht);
-							delete(Hf);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 				break;
@@ -351,23 +355,23 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
 					/* Alloca gli array temporanei rimappatura logaritmica */
 					if ((LF = new DLReal[Np]) == NULL)
 						{
-							delete(Ht);
-							delete(Hf);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 					if ((LM = new DLReal[Np]) == NULL)
 						{
-							delete(LF);
-							delete(Ht);
+							delete[](LF);
+							delete[](Ht);
 							delete(Hf);
 							return(False);
 						}
 					if ((LP = new DLReal[Np]) == NULL)
 						{
-							delete(LM);
-							delete(LF);
-							delete(Ht);
-							delete(Hf);
+							delete[](LM);
+							delete[](LF);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 
@@ -388,18 +392,18 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
 
 					if (CSLCASplineValue(LF,LM,LP,Np,&Hf[1],HtSize-1,&Ht[1],CSLHSSpline,CSLLogXLogY) == False)
 						{
-							delete(LP);
-							delete(LM);
-							delete(LF);
-							delete(Ht);
-							delete(Hf);
+							delete[](LP);
+							delete[](LM);
+							delete[](LF);
+							delete[](Ht);
+							delete[](Hf);
 							return(False);
 						}
 
 					/* Dealloca gli array temporanei rimappatura logaritmica */
-					delete(LP);
-					delete(LM);
-					delete(LF);
+					delete[](LP);
+					delete[](LM);
+					delete[](LF);
 				break;
 			}
 
@@ -420,7 +424,7 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
 
     if (IFft(Ht,HtSize2) == False)
       {
-        delete(Ht);
+        delete[](Ht);
         return(False);
       }
 
@@ -431,8 +435,8 @@ Boolean GenericFir(DLReal * Filter,unsigned int Order,DLReal * F,
     for(I = HalfFilter;I < Order;I++)
       Filter[I] = std::real(Ht[I-HalfFilter]);
 
-    delete(Ht);
-    delete(Hf);
+    delete[](Ht);
+    delete[](Hf);
     return(True);
   }
 
