@@ -21,11 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
 ****************************************************************************/
 
 /* Inclusioni */
@@ -40,6 +35,11 @@
 #include "convol.h"
 #include <math.h>
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 /* Inversione tramite Kirkeby fast deconvolution */
 Boolean KirkebyFDInvert(const DLReal * InSig, int InSigLen,DLReal * InvFilter,
 	int InvFilterLen, const DLReal * EffortSig, int EffortSigLen, DLReal EffortFactor,
@@ -155,9 +155,9 @@ Boolean KirkebyFDInvert(const DLReal * InSig, int InSigLen,DLReal * InvFilter,
 			InvFilter[I] = std::real<DLReal>(FFTArray1[J]);
 
 		/* Dealloca gli array temporanei */
-		delete FFTArray1;
+		delete[] FFTArray1;
 		if (EffortSig != NULL)
-			delete FFTArray2;
+			delete[] FFTArray2;
 
 		/* Operazione completata */
 		return True;
@@ -281,7 +281,7 @@ Boolean PEISMPKirkebyFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal *
 			}
 
 		/* Dealloca gli array temporanei */
-		delete AEPAbs;
+		delete[] AEPAbs;
 
 		/* Compone l'inverso componente MP e EP */
 		for (I = 0;I < FS;I++)
@@ -295,8 +295,8 @@ Boolean PEISMPKirkebyFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal *
 			InvFilter[I] = std::real<DLReal>(FFTArray1[J]);
 
 		/* Dealloca gli array temporanei */
-		delete FFTArray1;
-		delete FFTArray2;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
 
 		/* Operazione completata */
 		return True;
@@ -452,7 +452,7 @@ Boolean PEMSMPKirkebyFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal *
 			}
 
 		/* Dealloca gli array temporanei */
-		delete AEPAbs;
+		delete[] AEPAbs;
 
 		/* Compone l'inverso componente MP e EP */
 		for (I = 0;I < FS;I++)
@@ -466,8 +466,8 @@ Boolean PEMSMPKirkebyFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal *
 			InvFilter[I] = std::real<DLReal>(FFTArray1[J]);
 
 		/* Dealloca gli array temporanei */
-		delete FFTArray1;
-		delete FFTArray2;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
 
 		/* Operazione completata */
 		return True;
@@ -581,7 +581,7 @@ Boolean PETFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal * EPSig, in
 					EPIPERemove[I] = EPPFOut[J];
 
 				/* Dealloca gli array prefiltratura */
-				delete EPPFOut;
+				delete[] EPPFOut;
 
 				/* Segnala il resto della procedura */
 				sputs("Pre-echo truncation inversion completion...");
@@ -601,7 +601,7 @@ Boolean PETFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal * EPSig, in
 			FFTArray2[I] = EPIPERemove[I];
 
 		/* Dealloca l'array componente EP */
-		delete EPIPERemove;
+		delete[] EPIPERemove;
 
 		/* Porta nel dominio della frequenza */
 		Fft(FFTArray2,FS);
@@ -633,8 +633,8 @@ Boolean PETFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal * EPSig, in
 			InvFilter[I] = std::real<DLReal>(FFTArray1[J]);
 
 		/* Dealloca gli array temporanei */
-		delete FFTArray1;
-		delete FFTArray2;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
 
 		/* Operazione completata */
 		return True;
@@ -800,7 +800,7 @@ Boolean MRefPETFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal * EPSig
 							CMPNormFlat(EPIPERemove,FS,(DLReal) 1.0,OGainFactor,-1);
 
 						/* Dealloca gli array prefiltratura */
-						delete EPPFOut;
+						delete[] EPPFOut;
 					}
 
 				/* Copia l'array sorgente in quello temporaneo */
@@ -817,7 +817,7 @@ Boolean MRefPETFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal * EPSig
 						-std::arg(EPFDRef[I]));
 
 				/* Dealloca gli array temporanei */
-				delete EPFDRef;
+				delete[] EPFDRef;
 
 				/* Riporta nel dominio nel tempo */
 				IFft(FFTArray2,FS);
@@ -873,7 +873,7 @@ Boolean MRefPETFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal * EPSig
 					EPIPERemove[I] = EPPFOut[J];
 
 				/* Dealloca gli array prefiltratura */
-				delete EPPFOut;
+				delete[] EPPFOut;
 
 				/* Segnala il resto della procedura */
 				sputs("Pre-echo truncation inversion completion...");
@@ -889,7 +889,7 @@ Boolean MRefPETFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal * EPSig
 			FFTArray2[I] = EPIPERemove[I];
 
 		/* Dealloca l'array componente EP */
-		delete EPIPERemove;
+		delete[] EPIPERemove;
 
 		/* Porta nel dominio della frequenza */
 		Fft(FFTArray2,FS);
@@ -921,8 +921,8 @@ Boolean MRefPETFDInvert(const DLReal * MPSig, int MPSigLen, const DLReal * EPSig
 			InvFilter[I] = std::real<DLReal>(FFTArray1[J]);
 
 		/* Dealloca gli array temporanei */
-		delete FFTArray1;
-		delete FFTArray2;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
 
 		/* Operazione completata */
 		return True;
