@@ -21,11 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
 ****************************************************************************/
 
 /* Funzioni correzione e gestione livello del segnale */
@@ -37,6 +32,11 @@
 #include "dspwind.h"
 #include <math.h>
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 /* Calola il valore RMS del segnale Sig */
 DLReal GetRMSLevel(const DLReal * Sig,const int SigLen)
 	{
@@ -102,7 +102,7 @@ DLReal GetBLRMSLevel(const DLReal * Sig,const int SigLen,const int SampleFreq,
 		RMS = GetBLFFTRMSLevel(FFTArray,FFTSize,SampleFreq,StartFreq,EndFreq,W);
 
 		/* Dealloca l'array FFT */
-		delete FFTArray;
+		delete[] FFTArray;
 
 		/* Ritorna il valore RMS */
 		return RMS;
@@ -277,7 +277,7 @@ Boolean SigNormalize(DLReal * Sig,const int SigLen,const DLReal NormFactor,
 							PFA[I] = Sig[I];
 						if (Fft(PFA,SigLen) == False)
 							{
-								delete PFA;
+								delete[] PFA;
 								return False;
 							}
 						NormBase = (DLReal) 0.0;
@@ -289,12 +289,12 @@ Boolean SigNormalize(DLReal * Sig,const int SigLen,const DLReal NormFactor,
 							}
 						if (NormBase <= (DLReal) 0.0)
 							{
-								delete PFA;
+								delete[] PFA;
 								return False;
 							}
 						for (I = 0; I < SigLen; I++)
 							Sig[I] = (Sig[I] * NormFactor) / NormBase;
-						delete PFA;
+						delete[] PFA;
 					}
 				break;
 			}
@@ -413,7 +413,7 @@ Boolean LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLRe
 			Sig[I] = std::real(FFTArray[I]);
 
 		/* Dealloca l'array */
-		delete FFTArray;
+		delete[] FFTArray;
 
 		/* Operazione completata */
 		return True;
@@ -503,7 +503,7 @@ Boolean C1LPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DL
 			Sig[I] = std::real(FFTArray[I]);
 
 		/* Dealloca l'array */
-		delete FFTArray;
+		delete[] FFTArray;
 
 		/* Operazione completata */
 		return True;
@@ -676,9 +676,9 @@ Boolean HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const DLR
 			Sig[I] = std::real<DLReal>(FFTArray1[I]);
 
 		/* Dealloca gli array */
-		delete FFTArray1;
-		delete FFTArray2;
-		delete FFTArray3;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
+		delete[] FFTArray3;
 
 		/* Operazione completata */
 		return True;
@@ -826,9 +826,9 @@ Boolean C1HMPDipLimit(DLReal * Sig,const int SigLen,const DLReal MinGain,const D
 			Sig[I] = std::real<DLReal>(FFTArray1[I]);
 
 		/* Dealloca gli array */
-		delete FFTArray1;
-		delete FFTArray2;
-		delete FFTArray3;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
+		delete[] FFTArray3;
 
 		/* Operazione completata */
 		return True;
@@ -944,7 +944,7 @@ Boolean LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DLR
 			Sig[I] = std::real(FFTArray[I]);
 
 		/* Dealloca l'array */
-		delete FFTArray;
+		delete[] FFTArray;
 
 		/* Operazione completata */
 		return True;
@@ -1034,7 +1034,7 @@ Boolean C1LPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const D
 			Sig[I] = std::real(FFTArray[I]);
 
 		/* Dealloca l'array */
-		delete FFTArray;
+		delete[] FFTArray;
 
 		/* Operazione completata */
 		return True;
@@ -1207,9 +1207,9 @@ Boolean HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const DL
 			Sig[I] = std::real<DLReal>(FFTArray1[I]);
 
 		/* Dealloca gli array */
-		delete FFTArray1;
-		delete FFTArray2;
-		delete FFTArray3;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
+		delete[] FFTArray3;
 
 		/* Operazione completata */
 		return True;
@@ -1357,9 +1357,9 @@ Boolean C1HMPPeakLimit(DLReal * Sig,const int SigLen,const DLReal MaxGain,const
 			Sig[I] = std::real<DLReal>(FFTArray1[I]);
 
 		/* Dealloca gli array */
-		delete FFTArray1;
-		delete FFTArray2;
-		delete FFTArray3;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
+		delete[] FFTArray3;
 
 		/* Operazione completata */
 		return True;
@@ -1410,7 +1410,7 @@ Boolean LPNormFlat(DLReal * Sig,const int SigLen,const DLReal Gain,const DLReal
 			Sig[I] = std::real(FFTArray[I]);
 
 		/* Dealloca l'array */
-		delete FFTArray;
+		delete[] FFTArray;
 
 		/* Operazione completata */
 		return True;
@@ -1494,8 +1494,8 @@ Boolean CMPNormFlat(DLReal * Sig,const int SigLen,const DLReal Gain,const DLReal
 			Sig[I] = std::real<DLReal>(FFTArray1[I]);
 
 		/* Dealloca gli array */
-		delete FFTArray1;
-		delete FFTArray2;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
 
 		/* Operazione completata */
 		return True;
@@ -1582,9 +1582,9 @@ Boolean HMPNormFlat(DLReal * Sig,const int SigLen,const DLReal Gain,const DLReal
 			Sig[I] = std::real<DLReal>(FFTArray1[I]);
 
 		/* Dealloca gli array */
-		delete FFTArray1;
-		delete FFTArray2;
-		delete FFTArray3;
+		delete[] FFTArray1;
+		delete[] FFTArray2;
+		delete[] FFTArray3;
 
 		/* Operazione completata */
 		return True;
