@@ -21,11 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
 ****************************************************************************/
 
 /* Procedure a carattere psicoacustico e relative funzioni di supporto */
@@ -37,6 +32,11 @@
 #include "baselib.h"
 #include "dspwind.h"
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 /* Ritorna l'ampiezza di banda a frazioni di ottava
 per una data frequenza */
 DLReal FOctBWidth(const DLReal F,const DLReal FOW)
@@ -195,14 +195,14 @@ Boolean SpectralEnvelope(const DLReal * S,const int N,const int FS,
 		/* Calcola lo spettro del asegnale */
 		if (Fft(CSP,2 * N) == False)
 			{
-				delete CSP;
+				delete[] CSP;
 				return False;
 			}
 
 		/* Alloca l'array per l'estrazione dell'inviluppo */
 		if ((SP = new SEFloat[N + 1]) == NULL)
 			{
-				delete CSP;
+				delete[] CSP;
 				return False;
 			}
 
@@ -225,18 +225,18 @@ Boolean SpectralEnvelope(const DLReal * S,const int N,const int FS,
 			}
 
 		/* Dealloca l'array per l'estrazione dello spettro */
-		delete CSP;
+		delete[] CSP;
 
 		/* Alloca gli array per gli intervalli estrazione inviluppo */
 		if ((BU = new int[N]) == NULL)
 			{
-				delete SP;
+				delete[] SP;
 				return False;
 			}
 		if ((BL = new int[N]) == NULL)
 			{
-				delete BU;
-				delete SP;
+				delete[] BU;
+				delete[] SP;
 				return False;
 			}
 
@@ -304,9 +304,9 @@ Boolean SpectralEnvelope(const DLReal * S,const int N,const int FS,
 		/* Alloca l'array di supporto per l'estrazione dell'inviluppo */
 		if ((TSP = new SEFloat[N + 1]) == NULL)
 			{
-				delete BU;
-				delete BL;
-				delete SP;
+				delete[] BU;
+				delete[] BL;
+				delete[] SP;
 				return False;
 			}
 
@@ -346,10 +346,10 @@ Boolean SpectralEnvelope(const DLReal * S,const int N,const int FS,
 			SE[I] = (DLReal) (NF * ((TSP[BU[I]] - TSP[BL[I]]) / (BU[I] - BL[I])));
 
 		/* Dealloca gli array temporanei */
-		delete BL;
-		delete BU;
-		delete TSP;
-		delete SP;
+		delete[] BL;
+		delete[] BU;
+		delete[] TSP;
+		delete[] SP;
 
 		/* Operazione completata */
 		return True;
@@ -461,7 +461,7 @@ Boolean MKSETargetFilter(const DLReal * S,const int N,const int FS,
 					/* Calcola il filtro */
 					if (IFft(CSE,2 * N) == False)
 						{
-							delete CSE;
+							delete[] CSE;
 							return False;
 						}
 
@@ -473,7 +473,7 @@ Boolean MKSETargetFilter(const DLReal * S,const int N,const int FS,
 						}
 
 					/* Dealloca l'array per il calcolo filtro target */
-					delete CSE;
+					delete[] CSE;
 				break;
 
 				/* Fase minima */
@@ -520,7 +520,7 @@ Boolean MKSETargetFilter(const DLReal * S,const int N,const int FS,
 						TF[I] = std::real<DLReal>(CSE[I]);
 
 					/* Dealloca l'array per il calcolo filtro target */
-					delete CSE;
+					delete[] CSE;
 				break;
 			}
 
@@ -565,7 +565,7 @@ Boolean P2MKSETargetFilter(const DLReal * S,const int N,const int FS,
 		/* Alloca l'array per il filtro target */
 		if ((PTF = new DLReal[2 * PN]) == NULL)
 			{
-				delete PS;
+				delete[] PS;
 				return False;
 			}
 
@@ -578,8 +578,8 @@ Boolean P2MKSETargetFilter(const DLReal * S,const int N,const int FS,
 		/* Calcola il filtro target */
 		if (MKSETargetFilter(PS,PN,FS,BW,PDS,PTF,TFType,MinGain,DLStart,SampleFreq,StartFreq,EndFreq) == False)
 			{
-				delete PS;
-				delete PTF;
+				delete[] PS;
+				delete[] PTF;
 				return False;
 			}
 
@@ -608,8 +608,8 @@ Boolean P2MKSETargetFilter(const DLReal * S,const int N,const int FS,
 			}
 
 		/* Dealloca gli array temporanei */
-		delete PS;
-		delete PTF;
+		delete[] PS;
+		delete[] PTF;
 
 		/* Operazione completata */
 		return True;
