@@ -21,11 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
 ****************************************************************************/
 
 /* Prefiltratura a bande tramite sliding lowpass di un segnale */
@@ -35,6 +30,11 @@
 #include "level.h"
 #include "baselib.h"
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 /* Calcolo filtro passa basso finestrato Blackman */
 /* Il calcolo viene effettuato usando una ricorsione trigonometrica
 per migliorare le prestazioni di generazione */
@@ -359,6 +359,11 @@ void SLPreFilt(DLReal * InImp, const int IBS, const int FBS,
 		/* Sommatoria filtratura */
 		DLReal Sum;
 
+		/* Variabili per il Kahan summation algorithm */
+		DLReal SC;
+		DLReal SY;
+		DLReal ST;
+
 		/* Calcola inizio e fine della prefiltratura */
 		FilterBegin = (2 * StartFreq) / SampleFreq;
 		FilterEnd = (2 * EndFreq) / SampleFreq;
@@ -479,10 +484,16 @@ void SLPreFilt(DLReal * InImp, const int IBS, const int FBS,
 								FS = (CHFL + HEFL) - OCP;
 							}
 
-						/* Esegue la convoluzione */
-						Sum = 0;
+						/* Esegue la convoluzione, Kahan summation algorithm */
+						Sum = (DLReal) 0.0;
+						SC = (DLReal) 0.0;
 						for (J = FS,EI = IS;J < CFLM;J++,EI++)
-							Sum += InImp[EI] * FIRFilter[J];
+							{
+								SY = (InImp[EI] * FIRFilter[J]) - SC;
+								ST = Sum + SY;
+								SC = (ST - Sum) - SY;
+								Sum = ST;
+							}
 						OutImp[OCP] = Sum;
 					}
 
@@ -559,10 +570,16 @@ void SLPreFilt(DLReal * InImp, const int IBS, const int FBS,
 								FS = (CHFL + HEFL) - OCP;
 							}
 
-						/* Esegue la convoluzione */
-						Sum = 0;
+						/* Esegue la convoluzione, Kahan summation algorithm */
+						Sum = (DLReal) 0.0;
+						SC = (DLReal) 0.0;
 						for (J = FS,EI = IS;J < CFLM;J++,EI++)
-							Sum += InImp[EI] * FIRFilter[J];
+							{
+								SY = (InImp[EI] * FIRFilter[J]) - SC;
+								ST = Sum + SY;
+								SC = (ST - Sum) - SY;
+								Sum = ST;
+							}
 						OutImp[OCP] = Sum;
 					}
 
@@ -652,10 +669,16 @@ void SLPreFilt(DLReal * InImp, const int IBS, const int FBS,
 								FS = 0;
 							}
 
-						/* Esegue la convoluzione */
-						Sum = 0;
+						/* Esegue la convoluzione, Kahan summation algorithm */
+						Sum = (DLReal) 0.0;
+						SC = (DLReal) 0.0;
 						for (J = FS,EI = IS;J < CFLM;J++,EI++)
-							Sum += InImp[EI] * FIRFilter[J];
+							{
+								SY = (InImp[EI] * FIRFilter[J]) - SC;
+								ST = Sum + SY;
+								SC = (ST - Sum) - SY;
+								Sum = ST;
+							}
 						OutImp[OCP] = Sum;
 					}
 
@@ -732,10 +755,16 @@ void SLPreFilt(DLReal * InImp, const int IBS, const int FBS,
 								FS = 0;
 							}
 
-						/* Esegue la convoluzione */
-						Sum = 0;
+						/* Esegue la convoluzione, Kahan summation algorithm */
+						Sum = (DLReal) 0.0;
+						SC = (DLReal) 0.0;
 						for (J = FS,EI = IS;J < CFLM;J++,EI++)
-							Sum += InImp[EI] * FIRFilter[J];
+							{
+								SY = (InImp[EI] * FIRFilter[J]) - SC;
+								ST = Sum + SY;
+								SC = (ST - Sum) - SY;
+								Sum = ST;
+							}
 						OutImp[OCP] = Sum;
 					}
 
@@ -789,6 +818,6 @@ void SLPreFilt(DLReal * InImp, const int IBS, const int FBS,
 			}
 
 		/* Dealloca gli array intermedi */
-		delete FIRFilter;
-		delete FWin;
+		delete[] FIRFilter;
+		delete[] FWin;
 	}
