@@ -21,15 +21,6 @@
 
 				d.sbragion@infotecna.it
 
-		This program uses the parsecfg library from Yuuki  NINOMIYA.  De
-		tails  on  this  library  can be found in the parsecfg.c and par
-		secfg.h files.  Many thanks to Yuuki NINOMIYA for this useful li
-		brary.
-
-		This program uses  also the FFT  routines from  Takuya Ooura and
-		the GNU Scientific  Library (GSL).  Many thanks  to Takuya Ooura
-		and the GSL developers for these efficient routines.
-
 ****************************************************************************/
 
 /* Spline routines */
@@ -39,6 +30,11 @@
 #include <stdlib.h>
 #include <math.h>
 
+/* Memory leaks debugger */
+#ifdef DebugMLeaks
+	#include "debug_new.h"
+#endif
+
 /* Valore della spline lineare nel punto X */
 DLReal L1SplineValue(const DLReal * XN, const DLReal * YN,
 	const int N, const DLReal X)
@@ -734,7 +730,7 @@ Boolean AB3CRMSplineValue(const DLReal * XN, const DLReal * YN,
 		/* Alloca l'array rimappatura parametro */
 		if ((IX = new DLReal[XS]) == NULL)
 			{
-				delete SX;
+				delete[] SX;
 				return(False);
 			}
 
@@ -742,13 +738,13 @@ Boolean AB3CRMSplineValue(const DLReal * XN, const DLReal * YN,
 		AB3CRSplineValue(SX,Y,XP,X,XS,IX);
 
 		/* Dealloca l'array interpolazione parametro */
-		delete SX;
+		delete[] SX;
 
 		/* Interpolazione spline */
 		AB3SplineValue(XN,YN,N,IX,XS,Y);
 
 		/* Dealloca l'array rimappatura parametro */
-		delete IX;
+		delete[] IX;
 
 		/* Operazione completata */
 		return True;
@@ -1030,7 +1026,7 @@ Boolean AB3HSMSplineValue(const DLReal * XN, const DLReal * YN,
 		/* Alloca l'array rimappatura parametro */
 		if ((IX = new DLReal[XS]) == NULL)
 			{
-				delete SX;
+				delete[] SX;
 				return(False);
 			}
 
@@ -1038,13 +1034,13 @@ Boolean AB3HSMSplineValue(const DLReal * XN, const DLReal * YN,
 		APCHIPSplineValue(SX,Y,XP,X,XS,IX);
 
 		/* Dealloca l'array interpolazione parametro */
-		delete SX;
+		delete[] SX;
 
 		/* Interpolazione spline */
 		AB3SplineValue(XN,YN,N,IX,XS,Y);
 
 		/* Dealloca l'array rimappatura parametro */
-		delete IX;
+		delete[] IX;
 
 		/* Operazione completata */
 		return True;
@@ -1087,7 +1083,7 @@ Boolean CSLASplineValue(const DLReal * XN, const DLReal * YN,
 						return(False);
 					if ((XSE = new DLReal[XS]) == NULL)
 						{
-							delete XNE;
+							delete[] XNE;
 							return(False);
 						}
 
@@ -1121,15 +1117,15 @@ Boolean CSLASplineValue(const DLReal * XN, const DLReal * YN,
 						return(False);
 					if ((XSE = new DLReal[XS]) == NULL)
 						{
-							delete XNE;
+							delete[] XNE;
 							return(False);
 						}
 
 					/* Alloca l'array per l'asse Y */
 					if ((YNE = new DLReal[N]) == NULL)
 						{
-							delete XNE;
-							delete XSE;
+							delete[] XNE;
+							delete[] XSE;
 							return(False);
 						}
 
@@ -1161,7 +1157,7 @@ Boolean CSLASplineValue(const DLReal * XN, const DLReal * YN,
 							/* Prepara le derivate spline */
 							if (SplinePrepare(XNE,YNE,N,(DLReal) 0.0,(DLReal) 0.0,SplineBNat,SPD2YNR) == False)
 								{
-									delete SPD2YNR;
+									delete[] SPD2YNR;
 									RV = False;
 								}
 
@@ -1196,8 +1192,8 @@ Boolean CSLASplineValue(const DLReal * XN, const DLReal * YN,
 
 				case CSLLogXLinY:
 					/* Dealloca gli array */
-					delete XNE;
-					delete XSE;
+					delete[] XNE;
+					delete[] XSE;
 				break;
 
 				case CSLLinXLogY:
@@ -1206,7 +1202,7 @@ Boolean CSLASplineValue(const DLReal * XN, const DLReal * YN,
 						Y[I] = (DLReal) pow(10,Y[I]);
 
 					/* Dealloca gli array */
-					delete YNE;
+					delete[] YNE;
 				break;
 
 				case CSLLogXLogY:
@@ -1215,9 +1211,9 @@ Boolean CSLASplineValue(const DLReal * XN, const DLReal * YN,
 						Y[I] = (DLReal) pow(10,Y[I]);
 
 					/* Dealloca gli array */
-					delete XNE;
-					delete XSE;
-					delete YNE;
+					delete[] XNE;
+					delete[] XSE;
+					delete[] YNE;
 				break;
 			}
 
@@ -1249,7 +1245,7 @@ Boolean CSLCASplineValue(const DLReal * XN, const DLReal * MN,
 		/* Effettua l'interpolazione dell'ampiezza */
 		if (CSLASplineValue(XN,MN,N,X,XS,YV,SplineType,AxisType) == False)
 			{
-				delete YV;
+				delete[] YV;
 				return(False);
 			}
 
@@ -1277,7 +1273,7 @@ Boolean CSLCASplineValue(const DLReal * XN, const DLReal * MN,
 		/* Effettua l'interpolazione sulla fase */
 		if (CSLASplineValue(XN,PN,N,X,XS,YV,SplineType,PAT) == False)
 			{
-				delete YV;
+				delete[] YV;
 				return(False);
 			}
 
@@ -1286,7 +1282,7 @@ Boolean CSLCASplineValue(const DLReal * XN, const DLReal * MN,
 			Y[I] = std::polar<DLReal>(Y[I].real(),YV[I]);
 
 		/* Dealloca l'array intermedio */
-		delete YV;
+		delete[] YV;
 
 		/* Operazione completata */
 		return True;
